@@ -104,14 +104,6 @@ void CAddFriend::Localize(){
 void CAddFriend::OnAddBtn(wxEvent& evt) {
 
 
-//	if( GetDlgItem(IDC_USERNAME)->GetWindowTextLength()==0
-//		|| GetDlgItem(IDC_USERHASH)->GetWindowTextLength()!=32	){
-//		
-//			MessageBox(GetResString(IDS_ERR_NOVALIDFRIENDINFO));
-//			return;
-//	}
-
-	char buffer[256];
 	CString name,userhash, fullip;
 	uint32 ip;
 	uint16 port;
