@@ -174,7 +174,6 @@ void CBarShader::Draw(wxMemoryDC* dc, int iLeft, int iTop, bool bFlat) {
 	int iBytesInOnePixel = (int)(m_dBytesPerPixel + 0.5f);
 	uint32 start = 0;//bsCurrent->start;
 	uint32 drawnItems=0;
-	DWORD now=GetTickCount();
 	while(bsCurrent != NULL && rectSpan.right < (iLeft + m_iWidth)) {
 		uint32 uSpan = bsCurrent->end - start;
 		int iPixels = (int)(uSpan * m_dPixelsPerByte + 0.5f);
@@ -235,10 +234,7 @@ void CBarShader::FillRect(wxMemoryDC *dc, RECT* rectSpan, float fRed, float fGre
   if(rectSpan->right-rectSpan->left<1)
     return;
 
-  DWORD start=GetTickCount();
-  
   if(bFlat) {
-    DWORD color = RGB((int)(fRed + .5f), (int)(fGreen + .5f), (int)(fBlue + .5f));
     //dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(wxColour((int)(fRed+.5f),(int)(fGreen+.5f),(int)(fBlue+.5f)),wxSOLID)));
     wxBrush suti(wxColour((int)(fRed+.5f),(int)(fGreen+.5f),(int)(fBlue+.5f)),wxSOLID);
     dc->SetBrush(suti);
@@ -286,6 +282,5 @@ void CBarShader::FillRect(wxMemoryDC *dc, RECT* rectSpan, float fRed, float fGre
       dc->SetBrush(wxNullBrush);
     }
   }
-  DWORD end=GetTickCount();
   //printf(" FillRect took %d ms\n",end-start);
 }
