@@ -25,12 +25,12 @@
 #include "updownclient.h"
 #include "ClientList.h"
 #include "Friend.h"
-
-extern char* nstrdup(char*);
+#include "otherfunctions.h"
 
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <wx/hashmap.h>
 
 #ifdef _DEBUG
 #undef THIS_FILE
@@ -38,6 +38,11 @@ static char THIS_FILE[]=__FILE__;
 #define new DEBUG_NEW
 #endif
 
+// some client testing variables
+static wxString crash_name   = "[Invalid User Name]"; 
+static wxString empty_name = "[Empty User Name]";
+
+
 // prevent fscking dns queries
 class xmuleIPV4Address : public wxIPV4address {
 public:
@@ -52,7 +57,6 @@ public:
   }
 };
 
-
 //	members of CUpDownClient
 //	which are used by down and uploading functions 
 
@@ -79,6 +83,7 @@ CUpDownClient::CUpDownClient(uint16 in_port, uint32 in_userid,uint32 in_serverip
 void CUpDownClient::Init(){
 	memset(m_szFullUserIP,0,21);
 	credits = 0;
+	memset(reqfileid, 0, sizeof reqfileid);
 	m_nAvDownDatarate = 0;
 	m_nAvUpDatarate = 0;
 	m_byChatstate = 0;
@@ -142,6 +147,7 @@ void CUpDownClient::Init(){
 	m_nSumForAvgDownDataRate = 0;
 	m_nSumForAvgUpDataRate = 0;
 	m_clientSoft=SO_UNKNOWN;
+	m_nClientVersion=0;
 	m_bRemoteQueueFull = false;
 	memset( m_achUserHash, 0, 16);
 	SetWaitStartTime();
@@ -157,10 +163,17 @@ void CUpDownClient::Init(){
 		strcpy(m_szFullUserIP,inet_ntoa(sockAddr.sin_addr));
 	}
 	sourcesslot=0;
+	// At the beginning, client is't a thief :)
+	leechertype = 0;
+	thief = false;
 }
 
 CUpDownClient::~CUpDownClient(){
-	//Beep(400,5);
+  /* Razor 1a - Modif by MikaelB */
+	if(reqfile != NULL){
+		reqfile->RemoveDownloadingSource(this);
+	}
+  /* End modif */
 
 	theApp.clientlist->RemoveClient(this);
 	if (m_Friend){
@@ -213,56 +226,141 @@ CUpDownClient::~CUpDownClient(){
 }
 
 void CUpDownClient::ProcessHelloPacket(char* pachPacket, uint32 nSize){
-	CSafeMemFile* data = new CSafeMemFile((BYTE*)pachPacket,nSize);
+	CSafeMemFile data((BYTE*)pachPacket,nSize);
 	uint8 hashsize;
-	data->Read(&hashsize,1);
-	this->ProcessHelloTypePacket(data);
-	delete data;
+	if ( (1!=data.Read(&hashsize,1)) )
+		throw CString("Invalid Hello packet: Short packet when reading hash size");
+	if ( 16 != hashsize ) {
+		/*
+		 * Hint: We can not accept other sizes here because:
+		 *       - the magic number is spread all over the source
+		 *       - the answer packet lacks the size field
+		 */
+		throw CString("Invalid Hello packet: Other userhash sizes than 16 are not implemented");
+	}
+
+	ProcessHelloTypePacket(&data);
 }
 
 void CUpDownClient::ProcessHelloAnswer(char* pachPacket, uint32 nSize){
-	CSafeMemFile* data = new CSafeMemFile((BYTE*)pachPacket,nSize);
-	this->ProcessHelloTypePacket(data);
-	delete data;
+	CSafeMemFile data((BYTE*)pachPacket,nSize);
+	ProcessHelloTypePacket(&data);
 }
 
 void CUpDownClient::ProcessHelloTypePacket(CSafeMemFile* data){
-	data->Read(&m_achUserHash,16);
+	try {
+#ifdef __DEBUG__
+		bool bDumpClientInfo = false;	// Setted if unusual happens
+#endif
+
+		if ( 16 != data->Read(&m_achUserHash,16) )
+			throw CInvalidPacket("short packet reading user hash");
 	uint32 nUserID;
-	data->Read(&nUserID,4);
+		if ( 4 != data->Read(&nUserID,4) )
+			throw CInvalidPacket("short packet reading user id");
 	if (!m_nUserID || nUserID < 16777216)
 		m_nUserID = nUserID;
-	data->Read(&m_nUserPort,2); // hmm clientport is sent twice - why?
+		if ( 2 != data->Read(&m_nUserPort,2) ) // hmm clientport is sent twice - why?
+			throw CInvalidPacket("short packet reading user port");
 	uint32	tagcount;
-	data->Read(&tagcount,4);
+		if ( 4 != data->Read(&tagcount,4) )
+			throw CInvalidPacket("short packet reading tag count");
+
+#ifdef __DEBUG__
+		if ( tagcount > 7 )
+			printf("Huh, unusual tagcount %lu in Hello packet\n", (unsigned long)tagcount);
+#endif
+
+		// TODO: Check if we get everything needed!
 
 	/* It seems that various Mules and Donkeys send tagcount 2, Old MLDonkey sends
 		tagcount 3, new mldonkeys 4. There are also some clients
 		sending tagcount 5 and 7, what are those? */
-	if (tagcount <= 7) {
-		for (int i = 0;i <= tagcount; i++){
+		for (uint32 i = 0;i < tagcount; i++){
 			CTag* temptag = new CTag(data);
-			switch(temptag->tag->specialtag){
+			if ( temptag->tag->tagname && !strcmp(temptag->tag->tagname, "pr") ) {
+				// EDonkey hybrid does send integer 1
+			} else switch(temptag->tag->specialtag){
 				case CT_NAME:
+				{
+					if ( temptag->GetType() != TAG_STRING )
+						throw CInvalidPacket("invalid data type for username");
+
+					// Verifying username for determining a thief
+					wxString oldusername;
+					bool bOldUser = false;
 					if (m_pszUsername)
+                	{
+               	    	bOldUser = true;
+				    	oldusername.Format("%s",m_pszUsername);					
+						delete[] m_pszUsername;
+						m_pszUsername = NULL; 
+					}
+                	m_pszUsername = NULL;
+					m_pszUsername = temptag->tag->stringvalue ? nstrdup(temptag->tag->stringvalue) : nstrdup(crash_name);
+				
+                	if(strcmp(m_pszUsername, "")==0)
+					{
+						delete[] m_pszUsername;
+						m_pszUsername = NULL;
+						m_pszUsername=nstrdup(empty_name);
+					}
+					// If username has changed
+					if ((bOldUser && (oldusername.CmpNoCase(m_pszUsername)!=0))
+						&& !thief)
+                	{
+				    	uint64 id = getUID();
+						uint32 dummy;
+						leechertype=0;		
+						if(theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
+							theApp.listensocket->offensecounter[id]++;
+						else 
+							theApp.listensocket->offensecounter[id] = (uint32) 1;
+						theApp.listensocket->offensecounter[0]++;
+		 		 	}				
+                }
+				break;
+				/*	if (m_pszUsername)
 						delete[] m_pszUsername;
 					m_pszUsername = nstrdup(temptag->tag->stringvalue);
-					break;
+					break;  */
 				case CT_VERSION:
+					if ( temptag->GetType() != TAG_INTEGER )
+						throw CInvalidPacket("invalid data type for version");
+
 					m_nClientVersion = temptag->tag->intvalue;
 					break;
 				case CT_PORT:
+					if ( temptag->GetType() != TAG_INTEGER )
+						throw CInvalidPacket("invalid data type for port number");
+
 					m_nUserPort = temptag->tag->intvalue;
 					break;
+
+				case CT_FRIENDSHARING:
+					// ignore this one
+					break;
+
+#ifdef __DEBUG__
+				default:
+					printf("Unknown tag %u in HelloAnswer\n", (unsigned int)temptag->tag->specialtag);
+					temptag->DumpToStdout();
+					bDumpClientInfo = true;
+					break;
+#endif
 			}
 			delete temptag;
 		}
-	} else {
-		printf("Filtered HelloTypePacket with invalid tagcount %d.\n", tagcount);
-	}
 
-	data->Read(&m_dwServerIP,4);
-	data->Read(&m_nServerPort,2);
+		// Make up a username if we get none
+		if ( !m_pszUsername ) {
+			m_pszUsername = nstrdup(empty_name);
+		}
+
+		if ( 4 != data->Read(&m_dwServerIP,4) )
+			throw CInvalidPacket("short packet reading server IP");
+		if ( 2 != data->Read(&m_nServerPort,2) )
+			throw CInvalidPacket("short packet reading server port");
 	// Hybrid now has an extra uint32.. What is it for?
 	// Also, many clients seem to send an extra 6? These are not eDonkeys or Hybrids..
 	if ( data->GetLength() - data->GetPosition() == 4 ){
@@ -279,6 +377,23 @@ void CUpDownClient::ProcessHelloTypePacket(CSafeMemFile* data){
 //		if( m_nClientVersion < 100 )
 //			m_nClientVersion *= 10;
 	}
+
+#ifdef __DEBUG__
+		if ( data->GetLength() != data->GetPosition() )
+		{
+			long extra = data->GetLength() - data->GetPosition();
+			printf("Additional data in hello packet: %ld bytes\n", extra);
+			if ( extra > 0 )
+			{
+				char *tmpbuffer = new char[extra];
+				extra = data->Read(tmpbuffer, extra);
+				HexDump(tmpbuffer, extra);
+				delete[] tmpbuffer;
+				bDumpClientInfo = true;
+			}
+		}
+#endif
+
 	// tecxx 1609 2002 - add client's servet to serverlist (Moved to uploadqueue.cpp)
 
 	if (socket) {
@@ -292,7 +407,7 @@ void CUpDownClient::ProcessHelloTypePacket(CSafeMemFile* data){
 		m_dwUserIP = sockAddr.sin_addr.s_addr;
 		strcpy(m_szFullUserIP,inet_ntoa(sockAddr.sin_addr));
 	} else {
-		printf("Socket error, avoided crash.\n");
+		printf("Huh, socket failure. Avoided crash this time.\n");
 	}
 
 	if (theApp.glob_prefs->AddServersFromClient()){
@@ -326,6 +441,99 @@ void CUpDownClient::ProcessHelloTypePacket(CSafeMemFile* data){
 		theApp.friendlist->RefreshFriend(m_Friend);
 	}
 	ReGetClientSoft();
+	
+#ifdef __DEBUG__
+		if ( bDumpClientInfo )
+		{
+			printf("from client with:");
+			if ( m_pszUsername )
+				printf(" Username '%s'", m_pszUsername);
+			printf(" Software: '%s'", m_clientVerString.c_str());
+			printf("\n");
+		}
+#endif
+	}
+	catch (CInvalidPacket e)
+	{
+#ifdef __DEBUG__
+		data->Seek(0);
+		char *tmpbuffer = new char[data->GetLength()];
+		if ( data->GetLength() == data->Read(tmpbuffer, data->GetLength()) )
+			HexDump(tmpbuffer, data->GetLength());
+		delete tmpbuffer;
+#endif
+
+		// Leave thing function, since there nothing more we
+		// can do about this packet
+		throw CString("Received invalid hello packet! - ") + e.what();
+	}
+	
+	// Thief detection
+	if(!thief)
+	{
+		// Stolen Hash detection [BlackRat]
+		uint64 id = getUID();
+		if(theApp.serverconnect->GetClientID()!= m_nUserID && memcmp(m_achUserHash, theApp.glob_prefs->GetUserHash(), 16)==0)
+    	{
+    		// This is a hasl stealer !
+			thief=true;
+			leechertype=5;		
+			uint32 dummy;
+			if(theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
+				theApp.listensocket->offensecounter[id]++;
+			else
+				theApp.listensocket->offensecounter[id] = (uint32) 1;
+		}
+
+		// Detection id change [BlackRat]
+		/*
+			There is still something to do here
+			Actually, due to problems with HashMap, everybody here is consider as id stealers...
+		*/
+		
+		uint64 lasthash;
+		uint64 thishash = 0;
+		for(int i = 0; i < 8; i++ )
+			thishash += GetUserHash()[i] << (i*8) ^ GetUserHash()[i+8] << (i*8);
+
+		if((theApp.listensocket->hashbase.find(id) != theApp.listensocket->hashbase.end()) &&
+		   ((lasthash = theApp.listensocket->hashbase[id]) != thishash))
+		{   
+			// id changed, this is a id stealer !
+			leechertype=4;
+			if(theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
+				theApp.listensocket->offensecounter[id]++;
+			else
+				theApp.listensocket->offensecounter[id] = (uint32) 1;
+			theApp.listensocket->offensecounter[0]++;
+		}
+		theApp.listensocket->hashbase[id] = thishash;  
+
+		// Famous stolen hashs/names [BlackRat]	
+		if(m_pszUsername && (
+		   strcmp(m_pszUsername, "pbwll") == 0 ||
+		   strcmp(m_pszUsername, "unix user") == 0 ||
+		   strstr(m_pszUsername, "Odin") == m_pszUsername) && 
+		   !thief) 
+	    {  
+			// This is a thief !!!
+			thief=true;
+		    leechertype=3;
+		    if(theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
+				theApp.listensocket->offensecounter[id]++;
+			else
+				theApp.listensocket->offensecounter[id] = 1;
+
+			theApp.listensocket->offensecounter[0]++;
+		}
+
+		if((theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end()) &&
+		   (theApp.listensocket->offensecounter[id] >= 3))
+		{
+			// Made suspicious actions....
+			thief=true;
+		} 
+	} 
 }
 
 void CUpDownClient::SendHelloPacket(){
@@ -379,6 +587,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer){
 	tag6.WriteTagToFile(data);
 	CTag tag7(ET_COMPATABLECLIENT,2);
 	tag7.WriteTagToFile(data);
+	// Maella end
 	Packet* packet = new Packet(data,OP_EMULEPROT);
 	delete data;
 	if (!bAnswer)
@@ -392,13 +601,21 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer){
 }
 
 void CUpDownClient::ProcessMuleInfoPacket(char* pachPacket, uint32 nSize){
+	try
+	{
+#ifdef __DEBUG__
+		bool bDumpClientInfo = false;
+#endif
+
 	CSafeMemFile* data = new CSafeMemFile((BYTE*)pachPacket,nSize);
 	m_byCompatableClient = 0;
-	data->Read(&m_byEmuleVersion,1);
+		if ( 1 != data->Read(&m_byEmuleVersion,1) )
+			throw CInvalidPacket("short packet reading emule version");
 	if( m_byEmuleVersion == 0x2B )
 		m_byEmuleVersion = 0x22;
 	uint8 protversion;
-	data->Read(&protversion,1);
+		if ( 1 != data->Read(&protversion,1) )
+			throw CInvalidPacket("short packet reading emule protocol version");
 
 	//implicitly supported options by older clients
 	if (protversion == EMULE_PROTOCOL) {
@@ -420,36 +637,139 @@ void CUpDownClient::ProcessMuleInfoPacket(char* pachPacket, uint32 nSize){
 	m_bEmuleProtocol = true;
 
 	uint32 tagcount;
-	data->Read(&tagcount,4);
-	if (tagcount <= 10) {
-	for (int i = 0;i <= tagcount; i++){
+		if ( 4 != data->Read(&tagcount,4) )
+			throw CInvalidPacket("short packet reading tag count");
+
+#ifdef __DEBUG__
+		if (tagcount > 10)
+			printf("Mule info packet with unusual tag count %lu\n", (unsigned long)tagcount);
+#endif
+		for (int i = 0;i < tagcount; i++){
 		CTag* temptag = new CTag(data);
 		switch(temptag->tag->specialtag){
 			case ET_COMPRESSION:
+					if ( temptag->GetType() != TAG_INTEGER )
+						throw CInvalidPacket("invalid data type for compression support flag");
 				m_byDataCompVer = temptag->tag->intvalue;
 				break;
 			case ET_UDPPORT:
+					if ( temptag->GetType() != TAG_INTEGER )
+						throw CInvalidPacket("invalid data type for UDP port");
 				m_nUDPPort = temptag->tag->intvalue;
 				break;
 			case ET_UDPVER:
+					if ( temptag->GetType() != TAG_INTEGER )
+						throw CInvalidPacket("invalid data type for UDP version");
 				m_byUDPVer = temptag->tag->intvalue;
 				break;
 			case ET_SOURCEEXCHANGE:
+					if ( temptag->GetType() != TAG_INTEGER )
+						throw CInvalidPacket("invalid data type for source exchange version");
 				m_bySourceExchangeVer = temptag->tag->intvalue;
 				break;
 			case ET_COMMENTS:
+					if ( temptag->GetType() != TAG_INTEGER )
+						throw CInvalidPacket("invalid data type for comments support flag");
 				m_byAcceptCommentVer = temptag->tag->intvalue;
 				break;
 			case ET_EXTENDEDREQUEST:
+					if ( temptag->GetType() != TAG_INTEGER )
+						throw CInvalidPacket("invalid data type for extended request version");
 				m_byExtendedRequestsVer = temptag->tag->intvalue;
 				break;
 			case ET_COMPATABLECLIENT:
+					if ( temptag->GetType() != TAG_INTEGER )
+						throw CInvalidPacket("invalid data type for compatible client id");
 				m_byCompatableClient = temptag->tag->intvalue;
 				break;
-		}
-		delete temptag;
+			// Support for tag ET_MOD_VERSION
+			case ET_MOD_VERSION:
+			{
+					if ( temptag->GetType() != TAG_STRING )
+						throw CInvalidPacket("invalid data type for Mod-version");
+				// Anti-leechermods [BlackRat]
+				wxString oldmodversion;
+				bool bOldMod = false;
+				if(m_clientModString.Cmp("") != 0)
+                {
+                    bOldMod=true;
+				    oldmodversion = m_clientModString;					
+					m_clientModString = "";
+				}
+                m_clientModString = "";
+				m_clientModString = temptag->tag->stringvalue;
+
+				// mod version changed ??
+                if (bOldMod && (oldmodversion != m_clientModString))
+                {
+					  // Thief !
+					  uint64 id = getUID();
+					  uint32 dummy;
+					  leechertype = 2;
+		              if(theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
+						  theApp.listensocket->offensecounter[id]++;
+		              else
+			              theApp.listensocket->offensecounter[id] = (uint32) 1;
+
+					  theApp.listensocket->offensecounter[0]++;		       
+		 		}				
+            } 
+            break;
+
+		 		case ET_FEATURES:
+					if ( temptag->GetType() != TAG_INTEGER )
+					{
+#ifdef __DEBUG__
+						printf("MuleInfo: invalid data type for feature flag\n");
+						bDumpClientInfo = true;
+#endif
+						break;
+		}  
+#ifdef __DEBUG__
+		 			if ( temptag->tag->intvalue & ~0x03 )
+		 			{
+		 				printf("MuleInfo: unknown features signaled with ET_FEATURES: %08x\n", temptag->tag->intvalue & ~0x03);
+						bDumpClientInfo = true;
 	}
+#endif
+
+		 			/*
+		 			 * The known bits 0 and 1 are for
+		 			 * SecIdent v1/v2.
+		 			 */
+		 			break;
+
+#ifdef __DEBUG__
+		 		case ET_TAROD:
+		 		case ET_TAROD_VERSION:
+		 		case ET_L2HAC:
+		 		case ET_MOD_LSD:
+				case ET_MOD_LSD_VERSION:
+				case ET_MOD_SECURE_COMMUNITY:
+				case ET_MOD_PROTOCOL:
+				case ET_MOD_Morph:
+				case ET_MOD_Morph_VERSION:
+				case ET_MOD_FUSION:
+				case ET_MOD_FUSION_VERSION:
+				case ET_MOD_MorTillo:
+				case ET_MOD_MorTillo_VERSION:
+				case ET_MOD_LOVELACE_VERSION:
+				case ET_MOD_OXY:
+				case ET_PLUS:
+				case ET_FEATURESET:
+		 			/* We merily know about this tags */
+		 			break;
+
+		 		default:
+					printf("Unknown tag %u in MuleInfo packet\n", (unsigned int)temptag->tag->specialtag);
+					temptag->DumpToStdout();
+					bDumpClientInfo = true;
+            				break;
+#endif
+			}  
+			delete temptag;
 	}
+
 	if( m_byDataCompVer == 0 ){
 		m_bySourceExchangeVer = 0;
 		m_byExtendedRequestsVer = 0;
@@ -457,6 +777,43 @@ void CUpDownClient::ProcessMuleInfoPacket(char* pachPacket, uint32 nSize){
 		m_nUDPPort = 0;
 	}
 	delete data;
+	ReGetClientSoft();
+	
+#ifdef __DEBUG__
+		if ( bDumpClientInfo )
+		{
+			printf("from client with:");
+			if ( m_pszUsername )
+				printf(" Username '%s'", m_pszUsername);
+			printf(" Software: '%s'", m_clientVerString.c_str());
+			printf(" Mods: '%s'", m_clientModString.c_str());
+			printf("\n");
+		}
+#endif
+	}
+	catch (CInvalidPacket e)
+	{
+		throw CString("Received invalid Mule info packet - ") + e.what();
+	}
+	
+	// Filtering Invalid Emule Clients [BlackRat]
+    if (((!GetMuleVersion() && (GetClientSoft()==SO_EMULE || GetClientSoft()==SO_OLDEMULE) && (GetVersion()==60 || !GetVersion()))
+	   || (!ExtProtocolAvailable() && GetClientSoft()==SO_EMULE && (GetVersion()==60 || !GetVersion())))
+	   && !thief)
+	{
+		// bad client : thief !
+		thief = true;
+		leechertype = 1;
+		uint64 id = getUID();
+		uint32 dummy;
+		if(theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
+			theApp.listensocket->offensecounter[id]++;
+		else
+		    theApp.listensocket->offensecounter[id] = (uint32) 1;
+
+		theApp.listensocket->offensecounter[0]++;
+	}
+
 }
 
 void CUpDownClient::SendHelloAnswer(){
@@ -503,25 +860,35 @@ void CUpDownClient::SendHelloTypePacket(CMemFile* data){
 
 
 void CUpDownClient::ProcessMuleCommentPacket(char* pachPacket, uint32 nSize){
-	if (nSize>2){
+	try
+	{
 		CSafeMemFile data((BYTE*)pachPacket,nSize);
 		int length;
-		data.Read(&m_iRate,sizeof(m_iRate));
-		data.Read(&length,sizeof(length));
+		if ( sizeof(m_iRate) != data.Read(&m_iRate,sizeof(m_iRate)) )
+			throw CInvalidPacket("short packet reading rating");
+		if ( sizeof(length) != data.Read(&length,sizeof(length)) )
+			throw CInvalidPacket("short packet reading comment length");
+	
 		reqfile->SetHasRating(true);
 		theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_RATINGRECV),m_pszClientFilename,m_iRate);
 		if (length>50) length=50;
 		if (length>0){
 			char* desc=new char[length+1];
 			memset(desc,0,length+1);
-			data.Read(desc,length);
+			if ( length != data.Read(desc,length) )
+				throw CInvalidPacket("short packet reading comment string");
 			theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_DESCRIPTIONRECV), m_pszClientFilename, desc);
 			m_strComment.Format("%s",desc);
 			reqfile->SetHasComment(true);
-			delete desc;
+			delete[] desc;
 		}
 
 	}
+	catch ( CInvalidPacket e )
+	{
+		printf("Invalid MuleComment packet - %s\n", e.what());
+		return;
+	}
 	if (reqfile->HasRating() || reqfile->HasComment()) theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(reqfile);
 }
 void CUpDownClient::Disconnected(){
@@ -708,27 +1075,61 @@ void CUpDownClient::ConnectionEstablished(){
 }
 
 void CUpDownClient::ReGetClientSoft(){
-	if (!m_pszUsername) {m_clientSoft=SO_UNKNOWN;return;}
-	if( m_bIsHybrid ) {m_clientSoft=SO_EDONKEYHYBRID;return;}
-	if( m_bIsNewMLD ) {m_clientSoft=SO_NEW_MLDONKEY;return;}
-	if (m_achUserHash[5] == 13 && m_achUserHash[14] == 110) {m_clientSoft= SO_OLDEMULE;return;}
+	do
+	{
+	if (!m_pszUsername) {m_clientSoft=SO_UNKNOWN;break;}
+	if( m_bIsHybrid ) {m_clientSoft=SO_EDONKEYHYBRID;break;}
+	if( m_bIsNewMLD ) {m_clientSoft=SO_NEW_MLDONKEY;break;}
+	if (m_achUserHash[5] == 13 && m_achUserHash[14] == 110) {m_clientSoft= SO_OLDEMULE;break;}
 	if (m_achUserHash[5] == 14 && m_achUserHash[14] == 111){
 		if( m_byCompatableClient == 1 ){
 			m_clientSoft= SO_CDONKEY;
-			return;
+			break;
 		}
 		else if( m_byCompatableClient == 2 ){
 			m_clientSoft= SO_xmule;
-			return;
+			break;
 		}
 		else{
 			m_clientSoft= SO_EMULE;
-			return;
+			break;
 		}
 	}
-	if (m_achUserHash[5] == 'M' && m_achUserHash[14] == 'L') {m_clientSoft= SO_MLDONKEY;return;}
+	if (m_achUserHash[5] == 'M' && m_achUserHash[14] == 'L') {m_clientSoft= SO_MLDONKEY;break;}
 	else
 		m_clientSoft=SO_EDONKEY;
+	}
+	while (0);
+	
+	// Format name of client
+	switch(GetClientSoft()){
+		case SO_EDONKEY:
+			m_clientVerString.Printf(_T("eDonkey v%u"), GetVersion());
+			break;
+		case SO_EDONKEYHYBRID:
+			m_clientVerString.Printf(_T("eDonkey Hybrid v%u"), GetVersion());
+			break;
+		case SO_EMULE:
+			m_clientVerString.Printf(_T("eMule v%02X"), GetMuleVersion());
+			break;
+		case SO_OLDEMULE:
+			m_clientVerString.Printf(_T("old eMule v%02X"), GetMuleVersion());
+			break;
+		case SO_CDONKEY:
+			m_clientVerString.Printf(_T("cDonkey v%02X"), GetMuleVersion());
+			break;
+		case SO_xmule:
+			m_clientVerString.Printf(_T("xmule v%02X"), GetMuleVersion());
+			break;			
+		case SO_MLDONKEY:
+			m_clientVerString = _T("Old MlDonkey");
+			break;
+		case SO_NEW_MLDONKEY:
+			m_clientVerString = _T("New MlDonkey");
+			break;
+		default:
+			m_clientVerString = GetResString(IDS_UNKNOWN);
+    }
 }
 
 
