@@ -122,7 +122,6 @@ void CClientCreditsList::LoadList()
 		CString strBakFileName;
 		strBakFileName.Format("%sclients.met.BAK", m_pAppPrefs->GetAppDir());
 		
-		DWORD dwBakFileSize = 0;
 		BOOL bCreateBackup = TRUE;
 
 		//HANDLE hBakFile = ::CreateFile(strBakFileName, GENERIC_READ, FILE_SHARE_READ, NULL,
@@ -151,9 +150,9 @@ void CClientCreditsList::LoadList()
 			file.Close(); // close the file before copying
 			//BOOL bResult = ::CopyFile(strFileName, strBakFileName, FALSE);
 			// safe? you bet it is
-			char cmdbuffer[512];
-			sprintf(cmdbuffer,"cp \"%s\" \"%s\"",strFileName.GetData(),strBakFileName.GetData());
-			system(cmdbuffer);
+			if ( !wxCopyFile(strFileName,strBakFileName) ) {
+				printf("info: Could not create backup file '%s'\n", strFileName.c_str());
+			}
 			//DWORD dwError;
 			//if (!bResult)
 			//{
