@@ -78,9 +78,9 @@ void CClientDetailDialog::OnBnClose(wxEvent& evt)
 #define GetDlgItem(a,b) wxStaticCast(FindWindowById((a)),b)
 
 BOOL CClientDetailDialog::OnInitDialog(){
-  //CDialog::OnInitDialog();
 	Localize();
 	char buffer[100];
+	
 	if (m_client->GetUserName())
 		GetDlgItem(ID_DNAME,wxStaticText)->SetLabel(m_client->GetUserName());
 	else
@@ -105,6 +105,10 @@ BOOL CClientDetailDialog::OnInitDialog(){
 			GetDlgItem(ID_DSOFT,wxStaticText)->SetLabel(_("eMule"));
 			if (m_client->GetMuleVersion()){
 				sprintf(buffer,"v0.%02X",m_client->GetMuleVersion());
+				if(m_client->GetClientModString().IsEmpty() == false)
+				{
+					sprintf(buffer, "[ %s ]", m_client->GetClientModString().c_str());
+				}
 				GetDlgItem(ID_DVERSION,wxStaticText)->SetLabel(buffer);
 			}
 			else	
