@@ -95,17 +95,22 @@ bool CUpDownClient::Compare(CUpDownClient* tocomp){
 		return (this->GetUserID() == tocomp->GetUserID() || (this->GetIP() && this->GetIP() == tocomp->GetIP()) );
 }
 
-void CUpDownClient::AskForDownload(){
-	if (theApp.listensocket->TooManySockets() && !(socket && socket->IsConnected()) ){
+void CUpDownClient::AskForDownload()
+{
+	int rank=GetRemoteQueueRank();
+	bool hotrank= (rank && rank <5);
+	if (theApp.listensocket->TooManySockets(hotrank) && !(socket && socket->IsConnected()) ){
 		if (GetDownloadState() != DS_TOOMANYCONNS)
 			SetDownloadState(DS_TOOMANYCONNS);
 		return;
 	}
+	if (socket) {
+		socket->hotrank = hotrank;
+	}
 	m_bUDPPending = false;
 	m_dwLastAskedTime = ::GetTickCount();
 	SetDownloadState(DS_CONNECTING);
-	TryToConnect();
-
+	TryToConnect(hotrank);
 }
 
 bool CUpDownClient::IsSourceRequestAllowed() {
@@ -270,11 +275,21 @@ bool CUpDownClient::AddRequestForAnotherFile(CPartFile* file){
 			return false;
 	}
 	m_OtherRequests_list.AddTail(file);
+	file->A4AFSourcesList.AddTail(this); /* Razor 1a - Modif by MikaelB */
 	return true;
 }
 
 void CUpDownClient::SetDownloadState(uint8 byNewState){
 	if (m_nDownloadState != byNewState){
+		
+		/* Razor 1a - Modif by MikaelB */
+		if (byNewState == DS_DOWNLOADING) {
+			reqfile->AddDownloadingSource(this);
+		} else if (m_nDownloadState == DS_DOWNLOADING) {
+			reqfile->RemoveDownloadingSource(this);
+		}
+		/* End modif */
+
 		if (m_nDownloadState == DS_DOWNLOADING ){
 			m_nDownloadState = byNewState;
 			for (POSITION pos = m_DownloadBlocks_list.GetHeadPosition();pos != 0;m_DownloadBlocks_list.GetNext(pos)){
@@ -703,7 +718,7 @@ void CUpDownClient::SetRemoteQueueRank(uint16 nr){
 	theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(this);
 }
 
-
+#if 0
 bool CUpDownClient::SwapToAnotherFile(bool bIgnoreNoNeeded){
 	if (GetDownloadState() == DS_DOWNLOADING)
 		return false;
@@ -746,6 +761,7 @@ bool CUpDownClient::SwapToAnotherFile(bool bIgnoreNoNeeded){
 		return false;
 
 }
+#endif
 
 void CUpDownClient::UDPReaskACK(uint16 nNewQR){
 	m_bUDPPending = false;
@@ -812,3 +828,210 @@ void CUpDownClient::UpdateDisplayedInfo(bool force) {
         m_lastRefreshedDLDisplay = curTick;
     }
 }
+
+/* Razor 1a - Modif by MikaelB
+   SwapToThisFile function */
+
+void CUpDownClient::SwapToThisFile(CPartFile* file)
+{
+  // Get the position of the file in other requests' list
+  POSITION position = this->m_OtherRequests_list.Find(file);
+  // If position isn't null
+  if(position)
+  {
+    // Remove file at position in other requests' list
+    this->m_OtherRequests_list.RemoveAt(position);
+    // Add file at the head of other requests' list
+    this->m_OtherRequests_list.AddHead(file);
+
+    // Some files
+    CPartFile *SwapFile, *TempFile, *RequestedFile;
+    TempFile = this->m_OtherRequests_list.GetHead();
+    RequestedFile = this->reqfile;
+
+    // If the file at the head of other requests' list isn't the requested file
+    // and isn't a file of download queue list
+    // and either file state is ready or empty...
+    if((TempFile != RequestedFile) &&
+       (theApp.downloadqueue->IsPartFile(TempFile)) &&
+       ((TempFile->GetStatus(false) == PS_READY) ||
+        (TempFile->GetStatus(false) == PS_EMPTY)))
+    {
+      // Then we can remove head file in other requests' list and save it into SwapFile
+      SwapFile = this->m_OtherRequests_list.RemoveHead();
+    }
+
+    // If we've found a file to swap
+    // and requested file's state is ready or empty ...
+    if((SwapFile) &&
+       ((RequestedFile->GetStatus(false) == PS_READY) ||
+        (RequestedFile->GetStatus(false) == PS_EMPTY)))
+    {
+      // Remove source from client in the download list
+      theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(this,SwapFile);
+      // Get position of this client in the sources list of requested file
+      position = RequestedFile->srclists[this->sourcesslot].Find(this);
+
+      // if position isn't null...
+      if(position)
+      {
+        // Remove source at position from the sources list of requested file
+        RequestedFile->srclists[this->sourcesslot].RemoveAt(position);
+        // Remove source of this client from requested file in the download list
+        theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(this,RequestedFile);
+
+        // Add this source in the A4AF sources list of the requested file
+        RequestedFile->A4AFSourcesList.AddTail(this);
+        // Add the requested file in the other requests' list
+        this->m_OtherRequests_list.AddTail(RequestedFile);
+        // Add source of requested file from this client in the download list
+        theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(RequestedFile,this,true);
+
+        // Update requested file's sources infos
+        RequestedFile->NewSrcPartsInfo();
+        // Update requested file's parts counts
+        RequestedFile->UpdateAvailablePartsCount();
+        // Set download state of this client to no
+        this->SetDownloadState(DS_NONE);
+        // Set requested file to 0
+        RequestedFile = 0;
+        // Set remote queue rank to 0
+        this->m_nRemoteQueueRank = 0;
+        // If  abyPartStatus isn't null
+        if(this->m_abyPartStatus)
+        {
+          // Delete abyPartStatus
+          delete[] this->m_abyPartStatus;
+          // Set it to null
+          this->m_abyPartStatus = 0;
+        }
+        // Set part count to
+        this->m_nPartCount = 0;
+        // Set last asked time to 0
+        this->m_dwLastAskedTime = 0;
+        // set irate to 0
+        this->m_iRate = 0;
+        // Set comment to ""
+        this->m_strComment = "";
+        // If pszClientFilename isn't null
+        if(this->m_pszClientFilename)
+        {
+          // Delete pszClientFilename
+          delete this->m_pszClientFilename;
+          // Set it to 0
+          this->m_pszClientFilename = 0;
+        }
+        // Set requested file to swapped file
+        this->reqfile = SwapFile;
+        // Add this source in the sources list of swapped file
+        SwapFile->srclists[this->sourcesslot].AddTail(this);
+        // Add source of swapped file from this client to download list
+        theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(SwapFile,this,false);
+      }
+    }
+    // Else if swapped file isn't null...
+    else if(SwapFile)
+    {
+      // Add it to other requests' list
+      this->m_OtherRequests_list.AddHead(SwapFile);
+      // Add this source to A4AF sources list of swapped file
+      this->m_OtherRequests_list.GetHead()->A4AFSourcesList.AddHead(this);
+    }
+    // Else...
+    else
+      // Add this source to A4AF sources list of swapped file
+      this->m_OtherRequests_list.GetHead()->A4AFSourcesList.AddHead(this);
+  }
+  // Else...
+  else
+    // Add this source to A4AF sources lisy of file
+    file->A4AFSourcesList.AddHead(this);
+}
+
+/* Razor 1a - Modif by MikaelB
+   Made some changes in SwapToAnoterFile function */
+bool CUpDownClient::SwapToAnotherFile()
+{
+	if (this->GetDownloadState() == DS_DOWNLOADING)
+		return false;
+
+	if(!this->m_OtherRequests_list.IsEmpty())
+	{
+		CPartFile* SwapTo = NULL;
+
+		POSITION pos, pos1, pos2;
+		for (pos1 = this->m_OtherRequests_list.GetHeadPosition();(pos2=pos1)!=NULL;)
+		{
+			this->m_OtherRequests_list.GetNext(pos1);
+			CPartFile* cur_file = this->m_OtherRequests_list.GetAt(pos2);
+			if (cur_file != this->reqfile
+			&& theApp.downloadqueue->IsPartFile(cur_file)
+			&& (cur_file->GetStatus(false) == PS_READY || cur_file->GetStatus(false) == PS_EMPTY))
+			{
+				SwapTo = cur_file;
+				this->m_OtherRequests_list.RemoveAt(pos2);
+				break;
+			}
+		}
+
+		if(SwapTo)
+		{
+			pos = SwapTo->A4AFSourcesList.Find(this);
+			if(pos)
+			{
+				SwapTo->A4AFSourcesList.RemoveAt(pos);
+				theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(this,SwapTo);
+
+				pos = this->reqfile->srclists[this->sourcesslot].Find(this);
+				if(pos)
+				{
+					this->reqfile->srclists[this->sourcesslot].RemoveAt(pos);
+					this->reqfile->RemoveDownloadingSource(this);
+					theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(this,this->reqfile);
+
+					if(this->reqfile->GetStatus(false) == PS_READY || this->reqfile->GetStatus(false) == PS_EMPTY)
+					{
+						this->reqfile->A4AFSourcesList.AddTail(this);
+						this->m_OtherRequests_list.AddTail(this->reqfile);
+						theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(this->reqfile,this,true);
+					}
+
+					this->reqfile->NewSrcPartsInfo();
+					this->reqfile->UpdateAvailablePartsCount();
+					this->SetDownloadState(DS_NONE);
+					this->reqfile = 0;
+
+					this->m_nRemoteQueueRank = 0;
+					if (this->m_abyPartStatus)
+					{
+						delete[] this->m_abyPartStatus;
+						this->m_abyPartStatus = 0;
+					}
+
+					this->m_nPartCount = 0; 
+					this->m_dwLastAskedTime = 0;
+					this->m_iRate=0;
+					this->m_strComment="";
+
+					if (this->m_pszClientFilename)
+					{
+						delete this->m_pszClientFilename;
+						this->m_pszClientFilename = 0;
+					}
+
+					this->reqfile = SwapTo;
+
+					SwapTo->srclists[this->sourcesslot].AddTail(this);
+					theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(SwapTo,this,false);
+
+					return true;
+				}
+			}
+		}
+		else if(SwapTo)
+			this->m_OtherRequests_list.AddHead(SwapTo);
+	}
+	return false;
+}
+
+/* End modif */
