@@ -44,6 +44,7 @@ CDownloadQueue::CDownloadQueue(CPreferences* in_prefs,CSharedFileList* in_shared
 	m_nDownDataOverheadFileRequestPackets = 0;
 	m_nDownDataOverheadOtherPackets = 0;
 	m_nDownDataOverheadServerPackets = 0;
+	m_nLastED2KLinkCheck = 0;
 }
 
 void CDownloadQueue::UpdateDisplayedInfo(bool force) {
@@ -98,7 +99,7 @@ void CDownloadQueue::Init(){
 	printf("Loading temp files from %s.\n",searchPath.GetData());
 	wxString fileName=::wxFindFirstFile(searchPath,wxFILE);
 	//while (!end){
-	while(!fileName.IsEmpty()) {  
+	while(!fileName.IsEmpty()) {
 	  //end = !ff.FindNextFile();
 	  //if (ff.IsDirectory())
 	  //	continue;
@@ -120,34 +121,6 @@ void CDownloadQueue::Init(){
 	  fileName=::wxFindNextFile();
 	}
 	//ff.Close();
-
-#if 0
-	//try recovering any part.met files
-	searchPath += ".backup";
-	end = !ff.FindFile(searchPath, 0);
-	while (!end){
-		end = !ff.FindNextFile();
-		if (ff.IsDirectory())
-			continue;
-		CPartFile* toadd = new CPartFile();
-		if (toadd->LoadPartFile(app_prefs->GetTempDir(),ff.GetFileName().GetBuffer())){
-			toadd->SavePartFile(); // resave backup
-			count++;
-			filelist.AddTail(toadd);			// to downloadqueue
-			if (toadd->GetStatus(true) == PS_READY)
-				sharedfilelist->SafeAddKFile(toadd); // part files are always shared files
-			theApp.xmuledlg->transferwnd->downloadlistctrl->AddFile(toadd);// show in downloadwindow
-
-			theApp.xmuledlg->AddLogLine(false, GetResString(IDS_RECOVERED_PARTMET), toadd->GetFileName());
-		}
-		else {
-			delete toadd;
-		}
-	}
-	ff.Close();
-#endif
-#warning RECOVERY NOT IMPLEMENTED	
-
 	if(count == 0) {
 		theApp.xmuledlg->AddLogLine(false,GetResString(IDS_NOPARTSFOUND));
 	} else {
@@ -171,7 +144,7 @@ CDownloadQueue::~CDownloadQueue(){
 // [InterCeptor]
 void CDownloadQueue::SavePartFiles(bool del /*= false*/) {
 	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos))
-	{	
+	{
 
 		filelist.GetAt(pos)->m_hpartfile.Flush();
 		filelist.GetAt(pos)->SavePartFile();
@@ -184,6 +157,7 @@ void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd){
 	if (IsFileExisting(toadd->GetFileHash()))
 		return;
 	CPartFile* newfile = new CPartFile(toadd);
+	if (!newfile) return;
 	if (newfile->GetStatus() == PS_ERROR){
 		delete newfile;
 		return;
@@ -192,7 +166,12 @@ void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd){
 }
 
 void CDownloadQueue::AddSearchToDownload(CString link){
+// Bodo: Why here not, but in
+// Bodo: void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd)?
+//	if (IsFileExisting("link->GetFileHash()"))
+//		return;
 	CPartFile* newfile = new CPartFile(link);
+	if (!newfile) return;
 	if (newfile->GetStatus() == PS_ERROR){
 		delete newfile;
 		return;
@@ -222,22 +201,23 @@ void CDownloadQueue::StartNextFile(){
 	if (pfile) pfile->ResumeFile();
 }
 
-void
-CDownloadQueue::AddFileLinkToDownload(CED2KFileLink* pLink)
-{
+void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink* pLink) {
 	CPartFile* newfile = new CPartFile(pLink);
+	if (!newfile) return;
 	if (newfile->GetStatus() == PS_ERROR){
 		delete newfile;
 		newfile=NULL;
+		// Bodo: no return?
+	} else {
+		AddDownload(newfile);
 	}
-	else AddDownload(newfile);
-	if(pLink->HasValidSources()) {
-		if (newfile) newfile->AddClientSources(pLink->SourcesList);
-		else{
+	if (pLink->HasValidSources()) {
+		if (newfile) { // Bodo: "no return?" seems to be ok...
+			newfile->AddClientSources(pLink->SourcesList);
+		} else {
 				CPartFile* partfile = GetFileByID((uchar*)pLink->GetHashKey());
 				if (partfile) partfile->AddClientSources(pLink->SourcesList);
 		}
-
 	}
 }
 
@@ -314,7 +294,7 @@ void CDownloadQueue::Process(){
 			SendNextUDPPacket();
 	}
 
-	// Check for new links once per second.	
+	// Check for new links once per second.
 	if ((::GetTickCount() - m_nLastED2KLinkCheck) >= 1000) {
 		wxString filename = filename.Format("%s/.xMule/ED2KLinks", getenv("HOME"));
 		if (wxFile::Exists(filename)) {
@@ -325,7 +305,7 @@ void CDownloadQueue::Process(){
 
 }
 
-CPartFile*	CDownloadQueue::GetFileByID(uchar* filehash){
+CPartFile* CDownloadQueue::GetFileByID(uchar* filehash){
 	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
 		if (!memcmp(filehash,filelist.GetAt(pos)->GetFileHash(),16))
 			return filelist.GetAt(pos);
@@ -333,15 +313,15 @@ CPartFile*	CDownloadQueue::GetFileByID(uchar* filehash){
 	return 0;
 }
 
-CPartFile*      CDownloadQueue::GetFileByIndex(int index){
+CPartFile* CDownloadQueue::GetFileByIndex(int index){
 //      if (index>=filelist.GetCount()) return 0;
-        int count=0;
- 
-        for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
-                if (count==index) return filelist.GetAt(pos);
-                count++;
-        }
-        return 0;
+	int count=0;
+
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+		if (count==index) return filelist.GetAt(pos);
+		count++;
+	}
+	return 0;
 }
 
 bool CDownloadQueue::IsPartFile(void* totest){
@@ -353,11 +333,18 @@ bool CDownloadQueue::IsPartFile(void* totest){
 
 void CDownloadQueue::CheckAndAddSource(CPartFile* sender,CUpDownClient* source){
 	// if we block loopbacks at this point it should prevent us from connecting to ourself
+	// Bodo: If one has running two clients running on the same system,
+	// Bodo: does this prevent us from conneting to the other client?
 	if(!source->HasLowID() && (source->GetUserID() & 0xFF) == 0x7F) {
 		delete source;
 		return;
 	}
-
+/*
+	if (IsBlacklisted(source)) {
+		delete source;
+		return;
+	}
+*/
 	// uses this only for temp. clients
 	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
 		CPartFile* cur_file = filelist.GetAt(pos);
@@ -389,7 +376,7 @@ void CDownloadQueue::CheckAndAddSource(CPartFile* sender,CUpDownClient* source){
 		source->reqfile = sender;
 	else
 		theApp.clientlist->AddClient(source,true);
-	
+
 	sender->srclists[source->sourcesslot].AddTail(source);
 	theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,source,false);
 	//theApp.xmuledlg->transferwnd.downloadlistctrl.UpdateItem(this);
@@ -428,6 +415,26 @@ bool CDownloadQueue::RemoveSource(CUpDownClient* toremove, bool	updatewindow){
 				cur_file->srclists[sl].RemoveAt(pos2);
 				cur_file->NewSrcPartsInfo();
 				removed = true;
+				/* Razor 1a - Modif by MikaelB */
+				if(!toremove->m_OtherRequests_list.IsEmpty())  {
+					POSITION pos3, pos4;
+					for(pos3=toremove->m_OtherRequests_list.GetHeadPosition();(pos4=pos3)!=NULL;) {
+						toremove->m_OtherRequests_list.GetNext(pos3);
+						POSITION pos5 = toremove->m_OtherRequests_list.GetAt(pos4)->A4AFSourcesList.Find(toremove);
+						if(pos5) {
+							toremove->m_OtherRequests_list.GetAt(pos4)->A4AFSourcesList.RemoveAt(pos5);
+							theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(toremove,toremove->m_OtherRequests_list.GetAt(pos4));
+							toremove->m_OtherRequests_list.RemoveAt(pos4);
+						}
+					}
+				}
+				cur_file->RemoveDownloadingSource(toremove);
+				if (updatewindow) {
+					toremove->SetDownloadState(DS_NONE);
+					theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(toremove, cur_file);
+				}
+				toremove->reqfile = NULL;
+				/* End modif */
 				break;
 			}
 		}
@@ -606,3 +613,132 @@ void CDownloadQueue::AddLinksFromFile() {
 	linksfile.Write();
 	wxRemoveFile(wxString::Format("%s/.xMule/ED2KLinks", getenv("HOME")));
 }
+
+/* Razor 1a - Modif by MikaelB
+   RemoveSourceFromPartFile function */
+   
+void CDownloadQueue::RemoveSourceFromPartFile(CPartFile* file, CUpDownClient* client, POSITION position)
+{
+	// Remove source at position in sources list of file
+	file->srclists[client->sourcesslot].RemoveAt(position);
+	// Update infos of file
+	file->NewSrcPartsInfo();
+	file->UpdateAvailablePartsCount();
+	// Set client download state to none
+	client->SetDownloadState(DS_NONE);
+	// Set client valid source to false
+	client->SetValidSource(false);
+	// Remove downloading source of client
+	file->RemoveDownloadingSource(client);
+	// Remove source of download list window
+	theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(client, file);
+	// Set requested file of client to 0
+	client->reqfile = 0;
+	// If other requests list of client isn't empty...
+	if(! client->m_OtherRequests_list.IsEmpty()) {
+		// Some positions
+		POSITION position, temp_position;
+		// For every position in other requests list of client...
+		for(position = client->m_OtherRequests_list.GetHeadPosition(); (temp_position = position) != NULL;) {
+			// Get next position in position
+			client->m_OtherRequests_list.GetNext(position);
+			// Get position of client in the A4AF sources list of file at current position in client's other requests list
+			POSITION position2 = client->m_OtherRequests_list.GetAt(temp_position)->A4AFSourcesList.Find(client);
+			// If such a position have been found
+			if(position2) {
+				// Remove this position of the A4AF sources list of file at current position in client's other requests list
+				client->m_OtherRequests_list.GetAt(temp_position)->A4AFSourcesList.RemoveAt(position2);
+				// Remove current position from the download list window
+				theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(client, client->m_OtherRequests_list.GetAt(temp_position));  
+				// Remove current position from client's other requests list
+				client->m_OtherRequests_list.RemoveAt(temp_position);
+			}
+		}
+	}
+	// If client's upload status id none
+	if(client->GetUploadState() == US_NONE) {
+		// Disconnect client
+		client->Disconnected();
+	}
+}
+
+/* End modif */
+
+/* Razor 1a - Modif by MikaelB
+   DisableAnyA4AFAuto function */
+   
+void CDownloadQueue::DisableAnyA4AFAuto(void)
+{
+	// For all position in filelist...
+	for(POSITION position = filelist.GetHeadPosition();position != NULL;filelist.GetNext(position)) {
+		// Get file at position in filelist
+		CPartFile* file = (CPartFile*) filelist.GetAt(position);
+		// If file has been found...
+		if(file != NULL)
+		// Disable A4AF Auto 
+		file->SetA4AFAuto(false);
+	}
+}
+
+/* End modif */
+void CDownloadQueue::ResetCatParts(int cat){
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+		CPartFile* cur_file = filelist.GetAt(pos);
+		if (cur_file->GetCategory()==cat) {
+			cur_file->SetCategory(0);
+		} else if (cur_file->GetCategory() > cat) {
+			cur_file->SetCategory(cur_file->GetCategory()-1);
+		}
+	}
+}
+
+void CDownloadQueue::SetCatPrio(int cat, uint8 newprio){
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+		CPartFile* cur_file = filelist.GetAt(pos);
+		if (cat==0 || cur_file->GetCategory()==cat) {
+			if (newprio==PR_AUTO) {
+				cur_file->SetAutoPriority(true);
+				cur_file->SetPriority(PR_HIGH);
+			}
+			else {
+				cur_file->SetAutoPriority(false);
+				cur_file->SetPriority(newprio);
+			}
+		}
+	}
+}
+
+void CDownloadQueue::SetCatStatus(int cat, int newstatus){
+	bool reset=false;
+	POSITION pos= filelist.GetHeadPosition();
+	while (pos != 0) {
+		CPartFile* cur_file = filelist.GetAt(pos);
+		if (!cur_file) {
+			continue;
+		}
+		if (cat == cur_file->GetCategory() || cat == 0) {
+			switch (newstatus) {
+				case MP_CANCEL:
+					cur_file->DeleteFile();
+					reset=true;
+					break;
+				case MP_PAUSE:
+					cur_file->PauseFile();
+					break;
+				case MP_STOP:
+					cur_file->StopFile();
+					break;
+				case MP_RESUME: 
+					if (cur_file->GetStatus()==PS_PAUSED) {
+						cur_file->ResumeFile();
+					}
+					break;
+			}
+		}
+		filelist.GetNext(pos);
+		if (reset) {
+			reset = false;
+			pos = filelist.GetHeadPosition();
+		}
+	}
+}
