@@ -63,8 +63,6 @@ CFileDetailDialog::CFileDetailDialog(wxWindow* parent,CPartFile* file)
   SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWFRAME));
 
   wxPanel* content=wxXmlResource::Get()->LoadPanel(this,"DLG_FILEDETAILS");
-  wxSize koko=content->GetSize();
-  //koko.SetHeight(koko.GetHeight()-120);
   SetSize(content->GetSize()); //koko);
 
   // oops this too..
@@ -358,7 +356,6 @@ void CFileDetailDialog::OnBnClickedFileinfo(wxEvent& evt)
 
 void CFileDetailDialog::TakeOver(wxEvent& evt) {
    wxListCtrl* pmyListCtrl; 
-   int itemPosition; 
 
    pmyListCtrl = (wxListCtrl*)GetDlgItem(IDC_LISTCTRLFILENAMES,wxListCtrl);
    if (pmyListCtrl->GetSelectedItemCount() > 0) {
