@@ -45,18 +45,27 @@ bool CFriendList::LoadList(){
 			return false;
 		uint8 header;
 		file.Open(strFileName);
-		file.Read(&header,1);
-		if (header != MET_HEADER){
+		try
+		{
+			if ( 1 != file.Read(&header,1) )
+				throw CInvalidPacket();
+			if (header != MET_HEADER)
+				throw CInvalidPacket();
+
+			uint32 nRecordsNumber;
+			if ( 4 != file.Read(&nRecordsNumber,4) )
+				throw CInvalidPacket();
+			for (uint32 i = 0; i < nRecordsNumber; i++) {
+				Record =  new CFriend();
+				Record->LoadFromFile(&file);
+				m_listFriends.Append(Record);//AddTail(Record);
+			}
+		}
+		catch ( CInvalidPacket )
+		{
 			file.Close();
 			return false;
 		}
-		uint32 nRecordsNumber;
-		file.Read(&nRecordsNumber,4);
-		for (uint32 i = 0; i != nRecordsNumber; i++) {
-			Record =  new CFriend();
-			Record->LoadFromFile(&file);
-			m_listFriends.Append(Record);//AddTail(Record);
-		}
 		file.Close();
 		return true;
 		//}
