@@ -48,6 +48,7 @@ CClientReqSocket::CClientReqSocket(CPreferences* in_prefs,CUpDownClient* in_clie
 	ResetTimeOutTimer();
 	deletethis = false;
 	deltimer = 0;
+	hotrank = false;
 
 	SetEventHandler(*theApp.xmuledlg,ID_SOKETTI);
 	SetNotify(wxSOCKET_CONNECTION_FLAG|wxSOCKET_INPUT_FLAG|wxSOCKET_OUTPUT_FLAG|wxSOCKET_LOST_FLAG);
@@ -73,7 +74,8 @@ void CClientReqSocket::ResetTimeOutTimer(){
 };
 
 bool CClientReqSocket::CheckTimeOut(){
-	if (::GetTickCount() - timeout_timer > CONNECTION_TIMEOUT){
+	if ((!hotrank && (::GetTickCount() - timeout_timer > CONNECTION_TIMEOUT))
+	     || (hotrank&&(::GetTickCount() - timeout_timer > (CONNECTION_TIMEOUT+FILEREASKTIME)))){
 		timeout_timer = ::GetTickCount();
 		Disconnect();
 		return true;
@@ -137,6 +139,7 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
 	  client = new CUpDownClient(this);
 	}
 	client->ProcessHelloPacket(packet,size);
+
 	// now we check if we now this client already. if yes this socket will
 	// be attached to the known client, the new client will be deleted
 	// and the var. "client" will point to the known client.
@@ -170,7 +173,7 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
       }
       case OP_FILEREQUEST:{
 	theApp.downloadqueue->AddDownDataOverheadFileRequest(size);
-	if (size == 16 || (size > 16 && client->GetExtendedRequestsVersion() > 0)){
+	if (size >= 16 ) {
 	  if (!client->GetWaitStartTime())
 	    client->SetWaitStartTime();
 	  uchar reqfileid[16];
@@ -233,7 +236,7 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
       case OP_FILEREQANSNOFIL:{
 	theApp.downloadqueue->AddDownDataOverheadFileRequest(size);
 	// DbT:FileRequest
-	if (size == 16) {
+	if (size >= 16) {
 	  // if that client do not have my file maybe has another different
 	  CPartFile* reqfile = theApp.downloadqueue->GetFileByID((uchar*)packet);
 	  if (!reqfile)
@@ -243,7 +246,7 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
 	  if (client) switch (client->GetDownloadState()) {
 	  case DS_ONQUEUE:
 	  case DS_NONEEDEDPARTS:
-	    if (!client->SwapToAnotherFile(false)) {
+	    if (!client->SwapToAnotherFile()) {
 	      theApp.downloadqueue->RemoveSource(client, true);
 	    }
 	    break;
@@ -351,7 +354,7 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
       case OP_SETREQFILEID:{
 	theApp.downloadqueue->AddDownDataOverheadFileRequest(size);
 	// DbT:FileRequest
-	if (size == 16){
+	if (size >= 16){
 	  if (!client->GetWaitStartTime())
 	    client->SetWaitStartTime();
 	  
@@ -405,8 +408,23 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
 	char* message = new char[length+1];
 	memcpy(message,packet+2,length);
 	message[length] = 0;
-	//theApp.xmuledlg->chatwnd->chatselector->ProcessMessage(client,message);
-#warning CHATSELECTOR       
+
+	// Ban Spammers
+	if (strstr(message,"chez.com/theworld") == 0 || strstr(message,"fullspeed.to/mison") == 0)
+	{
+		if (client)
+		{
+        	client->Ban();
+            client->thief = true;
+		}
+		theApp.xmuledlg->AddLogLine(false,"The spammer '%s' [%s:%i] using %s has just been banished",client->GetUserName(),client->GetFullIP(),client->GetUserPort(),client->GetClientVerString().c_str());
+	}
+	else
+	{
+		//theApp.emuledlg->chatwnd.chatselector.ProcessMessage(client,message);
+		#warning CHATSELECTOR 
+	}
+							
 	delete[] message;
 	break;
       }
@@ -416,11 +434,10 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
 	if (theApp.glob_prefs->CanSeeShares() == 0 ||					// everybody
 	    (theApp.glob_prefs->CanSeeShares() == 1 && client->IsFriend() ) )	// friend
 	  {
-	    CCKey bufKey;
-	    CKnownFile* cur_file;
-	    for (POSITION pos = theApp.sharedfiles->m_Files_map.GetStartPosition();pos != 0;){
-	      theApp.sharedfiles->m_Files_map.GetNextAssoc(pos,bufKey,cur_file);
-	      list.AddTail((void*&)cur_file);
+	    CKnownFileMap& filemap = theApp.sharedfiles->m_Files_map;
+	    for (CKnownFileMap::iterator pos = filemap.begin();
+	         pos != filemap.end(); pos++ ) {
+	      list.AddTail((void*&)pos->second);
 	    }
 	    theApp.xmuledlg->AddLogLine(true,GetResString(IDS_REQ_SHAREDFILES).GetData(),client->GetUserName(),client->GetUserID(),GetResString(IDS_ACCEPTED).GetData() );
 	  } else theApp.xmuledlg->AddLogLine(true,GetResString(IDS_REQ_SHAREDFILES),client->GetUserName(),client->GetUserID(),GetResString(IDS_DENIED).GetData() );
@@ -458,15 +475,24 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
       throw GetResString(IDS_ERR_INVALIDPACKAGE);
       }*/
   }
-  catch(CString error){
+  catch(CInvalidPacket)
+  {
+#ifdef __DEBUG__
+	printf("Uncatched invalid packet exception\n");
+#endif
+	client->SetDownloadState(DS_ERROR);
+	Disconnect();
+	return false;
+  }
+  catch(wxString error){
     if (client){
       client->SetDownloadState(DS_ERROR);	
       //TODO write this into a debugfile
       theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_ERR_CLIENTERROR)
-				       ,client->GetUserName(),client->GetFullIP(),error.GetBuffer());
+				       ,client->GetUserName(),client->GetFullIP(),error.GetData());
     }
     else
-      theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_ERR_BADCLIENTACTION),error.GetBuffer());
+      theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_ERR_BADCLIENTACTION),error.GetData());
     
     Disconnect();
     return false;
@@ -595,8 +621,8 @@ bool CClientReqSocket::ProcessExtPacket(char* packet, uint32 size, uint8 opcode)
 			  
 		}
 	}
-	catch(CString error){
-		theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_ERR_BADCLIENTACTION),error.GetBuffer());
+	catch(wxString error){
+		theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_ERR_BADCLIENTACTION),error.GetData());
 		if (client) client->SetDownloadState(DS_ERROR);		
 		Disconnect();
 		return false;
@@ -677,6 +703,7 @@ CListenSocket::CListenSocket(CPreferences* in_prefs,wxSockAddress& addr)
 	maxconnectionreached = 0;
 	m_OpenSocketsInterval = 0;
 	m_nPeningConnections = 0;
+	bListening = false;
 
 	SetEventHandler(*theApp.xmuledlg,ID_SOKETTI);
 	SetNotify(wxSOCKET_CONNECTION_FLAG|wxSOCKET_INPUT_FLAG|wxSOCKET_OUTPUT_FLAG);
@@ -797,8 +824,8 @@ void CListenSocket::RemoveSocket(CClientReqSocket* todel){
 }
 
 void CListenSocket::KillAllSockets(){
-	for (POSITION pos = socket_list.GetHeadPosition();pos != 0;pos = socket_list.GetHeadPosition()){
-		CClientReqSocket* cur_socket = socket_list.GetAt(pos);
+	for (POSITION pos = socket_list.GetHeadPosition();pos != 0;){
+		CClientReqSocket* cur_socket = socket_list.GetNext(pos);
 			if (cur_socket->client)
 				cur_socket->client->Destroy();
 			else
