@@ -2,7 +2,7 @@
 // Name:        notebook.cpp
 // Purpose:
 // Author:      Robert Roebling
-// Id:          $Id: MuleNotebook.cpp,v 1.5 2003/03/24 20:10:07 un-thesis Exp $
+// Id:          $Id: MuleNotebook.cpp,v 1.6 2003/06/21 23:33:27 madcat_ Exp $
 // Copyright:   (c) 1998 Robert Roebling, Vadim Zeitlin
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,6 +12,7 @@
 #endif
 
 #include "CMuleNotebookBase.h"
+#include "xmule.h"
 
 #if wxUSE_NOTEBOOK
 #include "wx/bitmap.h"
@@ -181,6 +182,26 @@ static gboolean gtk_notebook_leave_cb(GtkWidget* widget,GdkEventCrossing* event,
   return true;
 }
 
+// "click" (general)
+static gboolean gtk_notebook_button_gen(GtkWidget* widget,GdkEventButton* event,
+					gpointer user_data)
+{
+  if(event->button==3) {
+    CMuleNotebook* notebook=(CMuleNotebook*)user_data;
+    if(notebook->GetMouseListener()) {
+      // just send rightclick event to the given handler
+      wxMouseEvent evt(wxEVT_RIGHT_DOWN);
+      evt.SetEventObject(notebook);
+      evt.m_x=(int)floor(event->x);
+      evt.m_y=(int)floor(event->y);
+      //notebook->GetMouseListener()->ProcessEvent(evt);
+      wxPostEvent(notebook->GetMouseListener(),evt);
+      return true;
+    }
+  }
+  return false;
+}
+
 //
 // "click" (on a image)
 //
@@ -372,6 +393,8 @@ void CMuleNotebook::Init()
     m_pagesData.DeleteContents( TRUE );
     m_selection = -1;
     m_themeEnabled = TRUE;
+    
+    m_listener=NULL;
 }
 
 CMuleNotebook::CMuleNotebook()
@@ -826,6 +849,10 @@ bool CMuleNotebook::InsertPage( int position,
     gtk_signal_connect( GTK_OBJECT(m_widget), "switch_page",
       GTK_SIGNAL_FUNC(gtk_notebook_page_change_callback), (gpointer)this );
 
+    // for right button capture
+    gtk_signal_connect_after( GTK_OBJECT(m_widget), "button_press_event",
+    	GTK_SIGNAL_FUNC(gtk_notebook_button_gen),(gpointer)this);
+	
     return TRUE;
 }
 
