@@ -3,7 +3,7 @@
 // Purpose:     CMuleNotebook class
 // Author:      Robert Roebling
 // Modified by:
-// RCS-ID:      $Id: MuleNotebook.h,v 1.3 2003/03/19 13:52:18 tiku Exp $
+// RCS-ID:      $Id: MuleNotebook.h,v 1.5 2003/06/28 19:23:03 madcat_ Exp $
 // Copyright:   (c) Julian Smart and Robert Roebling
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
@@ -79,8 +79,11 @@ public:
     // sets the size of the tabs (assumes all tabs are the same size)
   void SetTabSize(const wxSize& sz);
 
-  wxMutex m_LockTabs;
-  
+  void SetMouseListener(wxEvtHandler* _listener) {m_listener=_listener;};
+  wxEvtHandler* GetMouseListener() {return m_listener;};
+
+  wxMutex m_LockTabs;  
+
   // operations
   // ----------
     // remove one page from the notebook
@@ -137,7 +140,8 @@ protected:
 private:
     // the padding set by SetPadding()
     int m_padding;
-
+    wxEvtHandler* m_listener;
+    
     DECLARE_DYNAMIC_CLASS(CMuleNotebook)
     DECLARE_EVENT_TABLE()
 };
