@@ -40,6 +40,7 @@
 #include "pixmaps/plusmldonk.ico.xpm"
 #include "pixmaps/eDonkeyHybrid.ico.xpm"
 #include "pixmaps/pluseDonkeyHybrid.ico.xpm"
+#include "pixmaps/thief.ico.xpm"
 
 // CQueueListCtrl
 
@@ -83,6 +84,8 @@ CQueueListCtrl::CQueueListCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxSiz
   imagelist.Add(wxBitmap(plusmldonk_ico));
   imagelist.Add(wxBitmap(eDonkeyHybrid_ico));
   imagelist.Add(wxBitmap(pluseDonkeyHybrid_ico));
+  // Add Thief icon 
+  imagelist.Add(wxBitmap(thief_ico));
   
   m_hTimer.SetOwner(this,2349);
   m_hTimer.Start(10000);
@@ -281,6 +284,11 @@ void CQueueListCtrl::RefreshClient(CUpDownClient* client) {
 
 void CQueueListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRect& rectHL,bool highlighted)
 {
+	/* Don't do any drawing if there's nobody watching. */
+	if ((!theApp.xmuledlg->transferwnd->windowtransferstate) || (theApp.xmuledlg->GetActiveDialog() != 2)) {
+		return;
+	}
+
   if(!theApp.xmuledlg->IsRunning())
     return;
 
@@ -376,6 +384,11 @@ void CQueueListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRec
 		image = 0;
 	    }
 	  }
+	  
+	  // Added Thief Icon [BlackRat]
+	  if(client->thief) 
+		  image = 9;
+						
 	  POINT point = {cur_rec.left, cur_rec.top+1};
 	  //imagelist.Draw(dc,image, point, ILD_NORMAL);
 	  imagelist.Draw(image,*dc,cur_rec.left,cur_rec.top+1,wxIMAGELIST_DRAW_TRANSPARENT);
