@@ -20,30 +20,36 @@
 #include "SafeFile.h"
 
 CSafeFile::CSafeFile(LPCSTR lpszFileName,UINT nOpenFlags)
-  :CFile(lpszFileName,(CFile::OpenMode)nOpenFlags) //CFile(lpszFileName,nOpenFlags)
-{}
+:CFile(lpszFileName,(CFile::OpenMode)nOpenFlags)
+//:CFile(lpszFileName,nOpenFlags)
+{
+	// Nothing to do here
+}
 
 CSafeFile::CSafeFile() : CFile() {}
 
-	
-UINT CSafeFile::Read(void* lpBuf,UINT nCount){
-	if (Tell()+nCount > Length())
-	  //AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
-	  return (UINT)-1;
+
+UINT CSafeFile::Read(void* lpBuf,UINT nCount) {
+	if (Tell()+nCount > Length()) {
+//		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
+		return (UINT)-1;
+	}
 	return CFile::Read(lpBuf,nCount);
 }
 
 
 CSafeMemFile::CSafeMemFile(BYTE* lpBuffer,UINT nBufferSize,UINT nGrowBytes)
-	:CMemFile(lpBuffer,nBufferSize,nGrowBytes)
-{}
+:CMemFile(lpBuffer,nBufferSize,nGrowBytes)
+{
+	// Nothing to do here
+}
 
 CSafeMemFile::CSafeMemFile(UINT nGrowBytes) : CMemFile(nGrowBytes) {}
 
-	
-UINT CSafeMemFile::Read(void* lpBuf,UINT nCount){
-	if (GetPosition()+nCount > this->GetLength())
-	  //AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
-	  return 0;
+UINT CSafeMemFile::Read(void* lpBuf,UINT nCount) {
+	if (GetPosition()+nCount > this->GetLength()) {
+//		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
+		return 0;
+	}
 	return CMemFile::Read(lpBuf,nCount);
 }
