@@ -38,6 +38,7 @@
 #include "wx/xrc/xmlres.h"
 #include "wx/xrc/xh_all.h"
 #include <wx/settings.h>
+#include <wx/tokenzr.h>
 
 
 #define ID_SEARCHTIMER 55219
@@ -291,8 +292,6 @@ CSearchDlg::CSearchDlg(wxWindow* pParent /*=NULL*/)
   //wxStaticCast(FindWindowById(ID_NOTEBOOK),CMuleNotebook)->SetStateImageList(&m_StateImageList);
 
   Localize();
-
-  searchlistctrl=NULL;
 }
 
 CSearchDlg::~CSearchDlg(){
@@ -367,39 +366,41 @@ typedef void (CSearchListCtrl::*slistFunc)(wxListEvent&);
 
 void CSearchDlg::OnBnClickedStarts(wxEvent& ev){
 // Just in case, abort previous global search.
-  OnBnClickedCancels(nullEvent);
-  wxTextCtrl* ctl=XRCCTRL(*this,"IDC_ELINK",wxTextCtrl);
-  if(ctl->GetLineText(0).Length()) {
-    wxString strlink=ctl->GetLineText(0);
-    if(strlink.Right(1)!="/") strlink+="/";
-    ctl->SetValue("");
-    try {
-      CED2KLink* pLink=CED2KLink::CreateLinkFromUrl(strlink);
-      assert(pLink!=0);
-      if(pLink->GetKind()==CED2KLink::kFile) {
-	theApp.downloadqueue->AddFileLinkToDownload(pLink->GetFileLink());
-      } else {
-	throw wxString(_("bad link"));
-      }
-      delete pLink;
-    } catch(wxString error) {
-      char buffer[200];
-      sprintf(buffer,GetResString(IDS_ERR_INVALIDLINK),error.GetData());
-      theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERR_LINKERROR),buffer);
-    }
-    return;
-  }
-
-#if 0
-  if (GetDlgItem(IDC_SWEB)->GetWindowTextLength()){
-    ShellOpenFile(CreateWebQuery());
-    return;
-  }
+	OnBnClickedCancels(nullEvent);
+	wxTextCtrl* ctl=XRCCTRL(*this,"IDC_ELINK",wxTextCtrl);
+  
+//  if(ctl->GetLineText(0).Length()) {
+#if defined(__WXGTK__)
+	wxStringTokenizer tkz(ctl->GetValue(), "\n");
+#elif defined(__WXMAC__)
+	wxStringTokenizer tkz(ctl->GetValue(), "\r");
+#elif defined(__WXMSW__)
+	wxStringTokenizer tkz(ctl->GetValue(), "\r\n");
 #endif
 
-  // start search
-  StartNewSearch();
+	while (tkz.HasMoreTokens()) {
+		wxString strlink = tkz.GetNextToken();
 
+		if(strlink.Right(1)!="/") { strlink+="/"; }
+		ctl->SetValue("");
+		try {
+			CED2KLink* pLink=CED2KLink::CreateLinkFromUrl(strlink);
+			assert(pLink!=0);
+			if(pLink->GetKind()==CED2KLink::kFile) {
+				theApp.downloadqueue->AddFileLinkToDownload(pLink->GetFileLink());
+			} else {
+				throw wxString(_("bad link"));
+			}
+			delete pLink;
+		} catch(wxString error) {
+			char buffer[200];
+			sprintf(buffer,GetResString(IDS_ERR_INVALIDLINK),error.GetData());
+			theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERR_LINKERROR),buffer);
+		}
+	}
+
+	// start a search
+	StartNewSearch();
 }
 
 void CSearchDlg::OnTimer(wxTimerEvent& evt){
@@ -440,10 +441,8 @@ void CSearchDlg::CreateNewTab(wxString searchString,uint32 nSearchID)
   searchprogress->SetRange(theApp.serverlist->GetServerCount()-1);
 
   GetParent()->Layout();
-  searchlistctrl=(CSearchListCtrl*)sizCont->FindWindowById(ID_SEARCHLISTCTRL,sizCont);
+  CSearchListCtrl *searchlistctrl=(CSearchListCtrl*)sizCont->FindWindowById(ID_SEARCHLISTCTRL,sizCont);
   searchlistctrl->Init(theApp.searchlist);
-  theApp.searchlist->SetOutputWnd(searchlistctrl);
-
   searchlistctrl->ShowResults(nSearchID);
 }
 
@@ -561,13 +560,13 @@ void CSearchDlg::DownloadSelected() {
 #endif
   int index=-1;
   // download from the selected page.
-  CSearchListCtrl* oldlist=searchlistctrl;
   CMuleNotebook* nb=XRCCTRL(*this,"ID_NOTEBOOK",CMuleNotebook);
+  wxMutexLocker slock(nb->m_LockTabs);
   if(nb->GetSelection()==-1) {
     return;
   }
 
-  searchlistctrl=(CSearchListCtrl*)nb->FindWindowById(ID_SEARCHLISTCTRL,nb->GetPage(nb->GetSelection()));
+  CSearchListCtrl* searchlistctrl=(CSearchListCtrl*)nb->FindWindowById(ID_SEARCHLISTCTRL,nb->GetPage(nb->GetSelection()));
 
   for(;;) {
     index=searchlistctrl->GetNextItem(index,wxLIST_NEXT_ALL,wxLIST_STATE_SELECTED);
@@ -575,8 +574,6 @@ void CSearchDlg::DownloadSelected() {
       break;
     theApp.downloadqueue->AddSearchToDownload((CSearchFile*)searchlistctrl->GetItemData(index));
   }
-  searchlistctrl=oldlist;
-
 }
 
 
@@ -645,7 +642,7 @@ void CSearchDlg::StartNewSearch(){
     wxString searchString;
     typeText=GetDlgItem(IDC_TypeSearch,wxChoice)->GetStringSelection();
     searchString=GetDlgItem(IDC_SEARCHNAME,wxTextCtrl)->GetValue();
-    theApp.searchlist->NewSearch(searchlistctrl,CString(typeText),m_nSearchID);
+    theApp.searchlist->NewSearch(CString(typeText),m_nSearchID);
     GetDlgItem(IDC_STARTS,wxControl)->Enable(false);
     GetDlgItem(IDC_CANCELS,wxControl)->Enable(true);
     canceld = false;
@@ -810,6 +807,7 @@ void CSearchDlg::StartNewSearch(){
       delete packet;
     }
     CreateNewTab(searchString,m_nSearchID);
+	//theApp.xmuledlg->UpdateBar();
   }
 }
 
@@ -864,11 +862,12 @@ void CSearchDlg::DeleteSearch(uint16 nSearchID){
 		  if (i++ == nb->GetPageCount()) { 
 		  	OnBnClickedCancels(nullEvent);
 		  }
-		  /*
-		    Force further actions on the searchlistctrl to fail
-		  */
-		  ((CSearchListCtrl *)slctrl)->InvalidateSearchId();
 
+		  /*
+		     Force further actions on the searchlistctrl to fail
+		   */
+		  ((CSearchListCtrl *)slctrl)->InvalidateSearchId();
+		 
 		  /*
 		    ToDo: remove searchlistctrl (slctrl) ?
 		  */
