@@ -24,38 +24,62 @@
 #include "wx/xrc/xmlres.h"
 #include "wx/xrc/xh_all.h"
 
-bool packetcheck; // Needed for checking if search packet was valid.
+// CARE: This will lock the notebook when it does find a control.
+//       Call the function UngetSearchListControl() to unlock the notebook. But
+//       only after you are done with the Control returned by this function.
+//
+static CSearchListCtrl* GetSearchListControl(uint32 nSearchID)
+{
+	CMuleNotebook* nb=XRCCTRL(*(theApp.xmuledlg->searchwnd),"ID_NOTEBOOK",CMuleNotebook);
+	if ( !nb ) return NULL;
+
+	nb->m_LockTabs.Lock();
+
+	for (int tabCounter=0; tabCounter < nb->GetPageCount(); tabCounter++) {
+		if(nb->GetUserData(tabCounter)==nSearchID) {
+			return (CSearchListCtrl*)theApp.xmuledlg->searchwnd->FindWindowById(ID_SEARCHLISTCTRL,nb->GetPage(tabCounter));
+		}
+	}
+
+	nb->m_LockTabs.Unlock();
+	return NULL;
+}
+
+static void UngetSearchListControl(CSearchListCtrl* ctrl)
+{
+	if ( !ctrl ) return;			// NB was already unlocked
+
+	CMuleNotebook* nb=XRCCTRL(*(theApp.xmuledlg->searchwnd),"ID_NOTEBOOK",CMuleNotebook);
+	nb->m_LockTabs.Unlock();
+}
 
 CSearchFile::CSearchFile(CFile* in_data,uint32 nSearchID){
 
 	m_nSearchID = nSearchID;
-	in_data->Read(&m_abyFileHash,16);
-	in_data->Read(&clientip,4);
-	in_data->Read(&clientport,2);
+	if ( 16 != in_data->Read(&m_abyFileHash,16) )
+		throw CInvalidPacket();
+	if ( 4 != in_data->Read(&clientip,4) )
+		throw CInvalidPacket();
+	if ( 2 != in_data->Read(&clientport,2) )
+		throw CInvalidPacket();
 	uint32 tagcount;
-	in_data->Read(&tagcount,4);
+	if ( 4 != in_data->Read(&tagcount,4) )
+		throw CInvalidPacket();
 	
-	/* Madcat - All packets with tagcount != 3 seem to be invalid, they will be filtered out here. */
-	packetcheck=false;
-	if (tagcount==3) {
-		for (int i=0; i<tagcount; i++){
+	for (uint32 i=0; i<tagcount; i++){
 			CTag* toadd = new CTag(in_data);
 			taglist.Add(toadd);
 		}
-		int iSize = 2;
 		char* tempName = GetStrTagValue(FT_FILENAME);
-		if( tempName != NULL && (strlen(tempName)>0) )
-			iSize = (int)strlen(tempName)+1;
+	if ( !tempName )
+		throw CInvalidPacket("No filename in search result");
+
+	int iSize = (int)strlen(tempName)+1;
+	if ( iSize < 2 ) iSize = 2;		// required by tag format
 		m_pszFileName = new char[iSize];
-		if (tempName == NULL) {
-			packetcheck=false;
-		} else {
 			strcpy(m_pszFileName,tempName);
-			packetcheck=true;
-		}
 		m_nFileSize = GetIntTagValue(FT_FILESIZE);
 	}
-}
 
 CSearchFile::~CSearchFile(){
 	for (int i = 0; i != taglist.GetSize();i++)
@@ -95,7 +119,6 @@ uint32 CSearchFile::GetSourceCount(){
 }
 
 CSearchList::CSearchList(){
-	outputwnd = 0;
 }
 
 CSearchList::~CSearchList(){
@@ -123,13 +146,17 @@ void CSearchList::RemoveResults( uint32 nSearchID){
 }
 
 void CSearchList::ShowResults( uint32 nSearchID){
-	//outputwnd->SetRedraw(false);
-	for (POSITION pos = list.GetHeadPosition(); pos !=0;list.GetNext(pos)){
-		if( ((CSearchFile*)list.GetAt(pos))->GetSearchID() == nSearchID ){
-			outputwnd->AddResult(list.GetAt(pos));
+	CSearchListCtrl* outputwnd = GetSearchListControl(nSearchID);
+	if ( outputwnd ) {
+		//outputwnd->SetRedraw(false);
+		for (POSITION pos = list.GetHeadPosition(); pos !=0;list.GetNext(pos)){
+			if( ((CSearchFile*)list.GetAt(pos))->GetSearchID() == nSearchID ){
+				outputwnd->AddResult(list.GetAt(pos));
+			}
 		}
+		//outputwnd->SetRedraw(true);
 	}
-	//outputwnd->SetRedraw(true);
+	UngetSearchListControl(outputwnd);
 }
 
 // Ok, nobody knows why is this here, so disabling it until someone needs it.
@@ -152,10 +179,7 @@ void CSearchList::ShowResults( uint32 nSearchID){
 	}
 #endif
 
-void CSearchList::NewSearch(CSearchListCtrl* in_wnd, CString resTypes, uint16 nSearchID){
-	if(in_wnd)
-		outputwnd = in_wnd;
-
+void CSearchList::NewSearch(CString resTypes, uint16 nSearchID){
 	resultType=resTypes;
 	m_nCurrentSearch = nSearchID;
 	myHashList="";
@@ -169,19 +193,31 @@ uint16 CSearchList::ProcessSearchanswer(char* in_packet, uint32 size, CUpDownCli
 	if(Sender) {
 	  theApp.xmuledlg->searchwnd->CreateNewTab(Sender->GetUserName(),(uint32)Sender);
 	}
-	#if 0
-		if (Sender)
-			theApp.xmuledlg->searchwnd.CreateNewTab(CString(Sender->GetUserName()),(uint32)Sender);
-	#endif
-	uint32 results;
-	packet->Read(&results,4);
-	uint32 mySearchID=( (Sender != NULL)? (uint32)Sender : m_nCurrentSearch);
-	foundFilesCount.SetAt(mySearchID,0);
-	for (int i = 0; i != results; i++){
-		CSearchFile* toadd = new CSearchFile(packet, mySearchID);
-		if (packetcheck) { // Make sure the packet is valid.
-			AddToList(toadd, (Sender != NULL) );
+
+	try
+	{
+		uint32 results;
+		if ( 4 != packet->Read(&results,4) )
+			throw CInvalidPacket("short packet reading search result count");
+		uint32 mySearchID=( (Sender != NULL)? (uint32)Sender : m_nCurrentSearch);
+		foundFilesCount.SetAt(mySearchID,0);
+
+		try
+		{
+			for (uint32 i = 0; i != results; i++){
+				CSearchFile* toadd = new CSearchFile(packet, mySearchID);
+				AddToList(toadd, (Sender != NULL) );
+			}
 		}
+		catch ( CStrangePacket )
+		{ }
+	}
+	catch ( CInvalidPacket e )
+	{
+#ifdef __DEBUG__
+		printf("Invalid search result packet: %s\n", e.what());
+		HexDump(in_packet, size);
+#endif
 	}
 
 	packet->Close();
@@ -191,8 +227,13 @@ uint16 CSearchList::ProcessSearchanswer(char* in_packet, uint32 size, CUpDownCli
 
 uint16 CSearchList::ProcessUDPSearchanswer(char* in_packet, uint32 size){
 	CSafeMemFile* packet = new CSafeMemFile((BYTE*)in_packet,size,0);
-	CSearchFile* toadd = new CSearchFile(packet, m_nCurrentSearch);
-	AddToList(toadd);
+	try
+	{
+		CSearchFile* toadd = new CSearchFile(packet, m_nCurrentSearch);
+		AddToList(toadd);
+	}
+	catch ( CStrangePacket )
+	{ }
 	packet->Close();
 	delete packet;
 	return GetResultCount();
@@ -204,32 +245,14 @@ bool CSearchList::AddToList(CSearchFile* toadd, bool bClientResponse){
 	if (!toadd->GetIntTagValue(FT_FILESIZE)) {
 		return false;
 	}
-	// locate the searchlistctrl responsible for this search
-	// and set outputlist temporarily to point to the correct control
-	CSearchListCtrl* oldlistctrl=outputwnd;
-	CMuleNotebook* nb=(CMuleNotebook*)XRCCTRL(*(theApp.xmuledlg->searchwnd),"ID_NOTEBOOK",CMuleNotebook);
-
-	wxMutexLocker slock(nb->m_LockTabs);
-
-	if(nb->GetPageCount()>0) {
-		int tabCounter=-1;
-		for(tabCounter=0;tabCounter<nb->GetPageCount();tabCounter++) {
-			if(nb->GetUserData(tabCounter)==toadd->GetSearchID())
-			break;
-		}
-		if(tabCounter>=0) {
-			outputwnd=(CSearchListCtrl*)(theApp.xmuledlg->searchwnd->FindWindowById(ID_SEARCHLISTCTRL,nb->GetPage(tabCounter)));
-		}
-	} else {
-		// No pages at all, abort right now or we crash few lines below.
-		return false;
-	}
+	
 	// If the result was not the type user wanted, drop it.
 	if (!bClientResponse && !(resultType == GetResString(IDS_SEARCH_ANY) || GetFiletypeByName(toadd->GetFileName())==resultType)){
 		delete toadd;
-		outputwnd=oldlistctrl;
 		return false;
 	}
+
+	CSearchListCtrl* outputwnd = GetSearchListControl(toadd->GetSearchID());
 	for (POSITION pos = list.GetHeadPosition(); pos != NULL; list.GetNext(pos)){
 		CSearchFile* cur_file = list.GetAt(pos);
 		if ( (!memcmp(toadd->GetFileHash(),cur_file->GetFileHash(),16)) && cur_file->GetSearchID() ==  toadd->GetSearchID()){
@@ -238,7 +261,7 @@ bool CSearchList::AddToList(CSearchFile* toadd, bool bClientResponse){
 				outputwnd->UpdateSources(cur_file);
 			}
 			delete toadd;
-			outputwnd=oldlistctrl;
+			UngetSearchListControl(outputwnd);
 			return true;
 		}
 	}
@@ -250,7 +273,7 @@ bool CSearchList::AddToList(CSearchFile* toadd, bool bClientResponse){
 	if (outputwnd) {
 		outputwnd->AddResult(toadd);
 	}
-	outputwnd=oldlistctrl;
+	UngetSearchListControl(outputwnd);
 	return true;
 }
 
