@@ -203,7 +203,7 @@ void CServerListCtrl::InitSort()
 }
 
 bool CServerListCtrl::Init(CServerList* in_list){ 
-  printf("Serverlist loaded.\n",in_list);
+  printf("Serverlist loaded.\n");
   server_list = in_list;
 
   InsertColumn(0,_("Server Name"),wxLIST_FORMAT_LEFT,150);
@@ -378,11 +378,11 @@ void CServerListCtrl::RefreshServer( CServer* server ){
   temp=wxString::Format( "%s : %i",server->GetAddress(),server->GetPort());
   SetItem(itemnr,1,temp);
   if(server->GetListName()){
-    temp=wxString::Format( server->GetListName());
+    temp=server->GetListName();
     SetItem(itemnr,0,temp);
   }
   if(server->GetDescription()){
-    temp=wxString::Format( server->GetDescription());
+    temp=server->GetDescription();
     SetItem(itemnr,2,temp);
   }
   if(1) { //server->GetPing()){
@@ -521,7 +521,6 @@ bool CServerListCtrl::ProcessEvent(wxEvent& evt) {
 	{
 	  if ( this->GetSelectedItemCount()>1 ) {
 	    CServer* aServer;
-	    uint32   newPosition=0;
 	    
 	    theApp.serverconnect->Disconnect();
 	    int pos=GetNextItem(-1,wxLIST_NEXT_ALL,wxLIST_STATE_SELECTED);
@@ -923,15 +922,15 @@ bool CServerListCtrl::StaticServerFileRemove(CServer *server)
 
 			// Compare, if not the same server write original line to temp file
 			if (strLine.Cmp(strTest) != 0)
-				fprintf(statictemp, buffer);
+				fprintf(statictemp, "%s", buffer);
 		}
 
 		fclose(staticservers);
 		fclose(statictemp);
 
 		// All ok, remove the existing file and replace with the new one
-		remove( StaticFilePath );
-		rename( StaticTempPath, StaticFilePath );
+		wxRemoveFile( StaticFilePath );
+		wxRenameFile( StaticTempPath, StaticFilePath );
 	}
 	catch (...)
 	{
