@@ -153,6 +153,8 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 		CServer* update;
 		switch(opcode){
 			case OP_SERVERMESSAGE:{
+				if ( size <= 1 )
+					throw wxString(_("short server message packet"));
 				char* buffer = new char[size-1];
 				memcpy(buffer,&packet[2],size-2);
 				buffer[size-2] = 0;
@@ -170,7 +172,7 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 						}
 					}
 				}
-				theApp.xmuledlg->AddServerMessageLine(buffer);
+				theApp.xmuledlg->AddServerMessageLine("%s", buffer);
 				delete[] buffer;
 				break;
 			}
@@ -242,7 +244,7 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 			case OP_SERVERSTATUS:{
 				// FIXME some statuspackets have a different size -> why? structur?
 				if (size < 8)
-					break;//throw "Invalid status packet";
+					throw wxString(_("Invalid status packet"));
 				uint32 cur_user;
 				memcpy(&cur_user,packet,4);
 				uint32 cur_files;
@@ -259,21 +261,30 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 			//<<--Working, but needs to be cleaned up.. 
 			case OP_SERVERIDENT:{ 
 				if (size<38) { 
-					theApp.xmuledlg->AddLogLine(false,GetResString(IDS_ERR_KNOWNSERVERINFOREC)); 
-					break;// throw "Invalid server info received"; 
+//					theApp.xmuledlg->AddLogLine(false,GetResString(IDS_ERR_KNOWNSERVERINFOREC)); 
+					throw GetResString(IDS_ERR_KNOWNSERVERINFOREC);
 				} 
 				char* buffer = new char[size-29]; 
 				CServer* update = theApp.serverlist->GetServerByAddress(cur_server->GetAddress(),cur_server->GetPort()); 
 				uint16 num,num2; 
-				char* temp=new char[size-38+1]; 
-				memcpy(buffer,&packet[30],size-30);// 1st 30 char contain only server address & fillers 
-				memcpy(&num,&buffer[0],2); // length of server_name 
-				memcpy(temp,&buffer[2],num); 
-				temp[num]=0;//close the string 
-				update->SetListName(temp); 
-				memcpy(&num2,&buffer[num+6],2); 
-				memcpy (temp,&buffer[num+8],num2); 
-				temp[num2]=0; //close the string 
+				memcpy(buffer,&packet[30],size-30);// 1st 30 char contain only server address & fillers
+				memcpy(&num,&buffer[0],2); // length of server_name
+				if ( (num+2) > (size-30) ) {
+					delete[] buffer;
+					throw GetResString(IDS_ERR_KNOWNSERVERINFOREC);
+				}
+				char* temp=new char[size-38+1];
+				memcpy(temp,&buffer[2],num);
+				temp[num]=0;//close the string
+				update->SetListName(temp);
+				memcpy(&num2,&buffer[num+6],2);
+				if ( (num2+num+8) > (size-30) ) {
+					delete[] temp;
+					delete[] buffer;
+					throw GetResString(IDS_ERR_KNOWNSERVERINFOREC);
+				}
+				memcpy (temp,&buffer[num+8],num2);
+				temp[num2]=0; //close the string
 				update->SetDescription(temp); 
 				theApp.xmuledlg->ShowConnectionState(true,update->GetListName()); 
 				theApp.xmuledlg->serverwnd->serverlistctrl->RefreshServer(update); 
@@ -286,16 +297,17 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 				{
 					CSafeMemFile* servers = new CSafeMemFile((BYTE*)packet,size);
 					unsigned char count;
-					servers->Read(&count, 1);// check if packet is valid 
-					if ((int32)(count*6 + 1) > size)	 // (servercount*(4bytes ip + 2bytes port) + 1byte servercount)
+					if ((1 != servers->Read(&count, 1)) || ((int32)(count*6 + 1) > size))	 // (servercount*(4bytes ip + 2bytes port) + 1byte servercount)
 						count = 0;
 					int addcount = 0;
 					while(count)
 					{
 						uint32 ip;
 						unsigned short port;
-						servers->Read(&ip, 4);
-						servers->Read(&port, 2);
+						if ( 4 != servers->Read(&ip, 4) )
+							break;
+						if ( 2 != servers->Read(&port, 2) )
+							break;
 						in_addr host;
 						host.s_addr=ip;
 						CServer* srv = new CServer(port, inet_ntoa(host));
@@ -341,8 +353,8 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 		}
 		return true;
 	}
-	catch(CString error){
-		theApp.xmuledlg->AddLogLine(false,GetResString(IDS_ERR_PACKAGEHANDLING),error.GetBuffer());
+	catch(wxString error){
+		theApp.xmuledlg->AddLogLine(false,GetResString(IDS_ERR_PACKAGEHANDLING),error.GetData());
 		SetConnectionState(CS_DISCONNECTED);
 		return false;
 	}
@@ -395,7 +407,6 @@ void CServerSocket::OnClose(int nErrorCode){
 }
 
 void CServerSocket::SetConnectionState(sint8 newstate){
-  sint8 oldstate = connectionstate;
   connectionstate = newstate;
   if (newstate < 1){
     serverconnect->ConnectionFailed(this);
