@@ -56,7 +56,7 @@ CServerWnd::CServerWnd(wxWindow* pParent /*=NULL*/)
   serverlistctrl=list;
 
   wxTextCtrl* cv=(wxTextCtrl*)FindWindowByName("serverInfo");
-  cv->AppendText(wxString(_("This is "))+wxString("xMule")+wxString(" ")+wxString(VERSION)+wxString(_(" (based on "))+wxString(_("eMule v"))+wxString(CURRENT_VERSION_LONG)+wxString(")\n"));
+  cv->AppendText(wxString(_("This is "))+wxString("xMule")+wxString(" ")+wxString(VERSION)+wxString(_(" (based on "))+wxString(_("eMule"))+wxString(")\n"));
   cv->AppendText(wxString(_("Visit http://www.xmule.org to check if a new version is available.\n")));
 //  cv->AppendText(GetResString(IDS_EMULEW)+wxString(" "));
 //  cv->AppendText(GetResString(IDS_EMULEW3)+wxString(" "));
@@ -148,7 +148,7 @@ void CServerWnd::UpdateServerMetFromURL(wxString strURL) {
   if(retval==0) {
     // wget succeeded. proceed with serverlist processing
     serverlistctrl->AddServermetToList(strTempFilename);
-    remove(strTempFilename);
+    wxRemoveFile(strTempFilename);
     theApp.serverlist->SaveServermetToFile();
   } else {
       theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_FAILEDDOWNLOADMET).GetData(), strURL.GetData());
@@ -170,7 +170,7 @@ void CServerWnd::UpdateServerMetFromURL(wxString strURL) {
   serverlistctrl.Hide();
   serverlistctrl.AddServermetToList(strTempFilename);
   serverlistctrl.Visable();
-  remove(strTempFilename);
+  wxRemoveFile(strTempFilename);
   theApp.serverlist->SaveServermetToFile();
 #endif
 }
@@ -246,7 +246,7 @@ void CServerWnd::OnBnClickedAddserver(wxEvent& evt){
     }
     delete toadd;
     theApp.xmuledlg->AddLogLine(true, GetResString(IDS_SRV_NOTADDED) );
-  } else theApp.xmuledlg->AddLogLine(true,GetResString(IDS_SERVERADDED)+wxString(toadd->GetListName()));
+  } else theApp.xmuledlg->AddLogLine(true,GetResString(IDS_SERVERADDED)+"%s", toadd->GetListName());
   theApp.serverlist->SaveServermetToFile();
 }
 
