@@ -19,6 +19,7 @@
 #ifndef _SHAREDFILESLIST_H
 #define _SHAREDFILESLIST_H
 
+#include <map>
 #include "wintypes.h"
 #include "opcodes.h"
 #include "xmule.h"
@@ -32,12 +33,17 @@
 #include "MapKey.h"
 #include <wx/thread.h>
 
+/*
 struct UnknownFile_Struct{
 	char* name;
 	char* directory;
+	CPartFile* partfile_Owner;
 };
+*/
+struct UnknownFile_Struct;
 
 class CKnownFileList;
+class CAddFileThread;
 
 #if 0
 WX_DECLARE_LIST(UnknownFileStruct,UnknownList);
@@ -48,7 +54,7 @@ public:
   CFilePtrList() : UnknownList()
     { };
   virtual ~CFilePtrList() 
-    { m_lockFilePtrList.Unlock(); };
+    { };
   
   int GetCount()	{ int nResult;
   wxMutexLocker locker(m_lockFilePtrList);
@@ -78,6 +84,8 @@ public:
 };
 #endif
 
+typedef std::map<CCKey,CKnownFile*> CKnownFileMap;
+
 class CSharedFileList{
 	friend class CSharedFilesCtrl;
 	friend class CClientReqSocket;
@@ -96,18 +104,17 @@ public:
 	CKnownFileList*		filelist;
 	void	CreateOfferedFilePacket(CKnownFile* cur_file,CMemFile* files);
 	uint64	GetDatasize();
-	uint16	GetCount()	{return m_Files_map.GetCount(); }
+	uint16	GetCount()	{return m_Files_map.size(); }
 	void	UpdateItem(CKnownFile* toupdate);
+	void	AddFilesFromDirectory(char* directory);
 private:
 	void	FindSharedFiles();
-	void	AddFilesFromDirectory(char* directory);
-	void	HashNextFile();
 
-	CMap<CCKey,CCKey,CKnownFile*,CKnownFile*&> m_Files_map;
-	CTypedPtrList<CPtrList, UnknownFile_Struct*> waitingforhash_list;
+	CKnownFileMap		m_Files_map;
 	CPreferences*		app_prefs;
 	CServerConnect*		server;
 	CSharedFilesCtrl*	output;
+	CAddFileThread*		m_Thread;
 };
 
 #if 0
@@ -148,25 +155,19 @@ private:
 };
 #endif
 
+/*
 //class CPartFile;
 #include "wx/thread.h"
 class CAddFileThread : public wxThread
 {
-  //		DECLARE_DYNCREATE(CAddFileThread)
 public:
 	CAddFileThread();
 public:
 	virtual	BOOL	InitInstance() {return true;}
-	//virtual int		Run();	
 	virtual ExitCode Entry();
 	virtual void OnExit() {}
 
-	void	SetValues(CSharedFileList* pOwner, char* directory, char* filename, CPartFile* in_partfile_Owner = 0,wxFrame* parent=NULL);
 private:
-	CSharedFileList* m_pOwner;
-	char*			 directory;
-	char*			 filename;
-	CPartFile*		 partfile_Owner;
-	wxFrame* parent;
 };
+*/
 #endif
