@@ -227,11 +227,8 @@ void CSharedFilesCtrl::Localize() {
 void CSharedFilesCtrl::ShowFileList(CSharedFileList* in_sflist){
 	DeleteAllItems();
 	sflist = in_sflist;
-	CCKey bufKey;
-	CKnownFile* cur_file;
-	for (POSITION pos = sflist->m_Files_map.GetStartPosition();pos != 0;){
-		sflist->m_Files_map.GetNextAssoc(pos,bufKey,cur_file);
-		ShowFile(cur_file);
+	for (CKnownFileMap::iterator pos = sflist->m_Files_map.begin();pos != sflist->m_Files_map.end();pos++){
+		ShowFile(pos->second);
 	}
 }
 
@@ -554,7 +551,6 @@ void CSharedFilesCtrl::OnColumnClick(wxListEvent& evt) {
                 SetSortArrow(sortItem, sortAscending);
         else
 	  SetSortArrow(sortItem, sortAscending); // ? arrowDoubleUp : arrowDoubleDown);
-#warning no double-arrow support ...
         SortItems(SortProc, sortItem + adder + (sortAscending ? 0:20));
                                                                                 
 }
