@@ -201,6 +201,7 @@ void CStatisticsDlg::Init()
   totalconnectionchecks = 0;
   averageconnections = 0;
   activeconnections = 0;  
+  maxDown = 0;
 }
 
 
@@ -288,7 +289,7 @@ void CStatisticsDlg::SetCurrentRate(float uploadrate, float downloadrate) {
         UpDown* updown=new UpDown();
         updown->upload = uploadrate;
         updown->download = downloadrate;
-//        theApp.webserver->AddStatsLine(updown);
+        theApp.webserver->AddStatsLine(updown);
 
 	// averages
 	m_dPlotDataDown[0]=	GetAvgDownloadRate(AVG_SESSION);
