@@ -34,7 +34,7 @@ typedef struct _tagSIZE {
 
 class CSysTray {
  public:
-  CSysTray(wxWindow* parent,int desktopMode);
+  CSysTray(wxWindow* parent,int desktopMode,const wxString& title);
 
   void Show(const wxChar* caption,int nMsgType,DWORD dwTimeToShow=500,DWORD dwTimeToStay=4000,DWORD dwTimeTOHide=200);
 
