@@ -24,9 +24,7 @@
 #include "xmule.h"
 #include "UploadQueue.h"
 #include "otherstructs.h"
-
-//#define nstrdup strdup
-extern char* nstrdup(char*);
+#include "otherfunctions.h"
 
 //	members of CUpDownClient
 //	which are mainly used for uploading functions 
@@ -324,8 +322,8 @@ bool CUpDownClient::CreateNextBlockPackage(){
 			filedata = 0;
 		}
 	}
-	catch(CString error){
-		theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_ERR_CLIENTERRORED),GetUserName(),error.GetBuffer());
+	catch(wxString error){
+		theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_ERR_CLIENTERRORED),GetUserName(),error.GetData());
 		theApp.uploadqueue->RemoveFromUploadQueue(this);
 		if (filedata)
 			delete filedata;
@@ -545,10 +543,10 @@ void CUpDownClient::FlushSendBlocks(){ // call this when you stop upload, or the
 void CUpDownClient::SendHashsetPacket(char* forfileid){
 	CKnownFile* file = theApp.sharedfiles->GetFileByID((uchar*)forfileid);
 	if (!file) {
-		printf("HashsetPacket error: Knownfile not found.\n");
+		theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_REQ_FNF));
 		return;
-		// throw GetResString(IDS_ERR_REQ_FNF)+CString(" (SendHashsetPacket)");
 	}
+
 	CMemFile* data = new CMemFile();
 	data->Write(file->GetFileHash(),16);
 	uint16 parts = file->GetHashCount();
