@@ -46,6 +46,7 @@ END_EVENT_TABLE()
 #include "pixmaps/plusmldonk.ico.xpm"
 #include "pixmaps/eDonkeyHybrid.ico.xpm"
 #include "pixmaps/pluseDonkeyHybrid.ico.xpm"
+#include "pixmaps/thief.ico.xpm"
 
 //IMPLEMENT_DYNAMIC(CUploadListCtrl, CMuleListCtrl)
 CUploadListCtrl::CUploadListCtrl(){
@@ -80,6 +81,9 @@ CUploadListCtrl::CUploadListCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxS
   imagelist.Add(wxBitmap(plusmldonk_ico));
   imagelist.Add(wxBitmap(eDonkeyHybrid_ico));
   imagelist.Add(wxBitmap(pluseDonkeyHybrid_ico));
+  
+  // Added a Thief icon [BlackRat]				
+  imagelist.Add(wxBitmap(thief_ico));
 }
 
 void CUploadListCtrl::Init(){
@@ -429,6 +433,11 @@ int CUploadListCtrl::SortProc(long lParam1, long lParam2, long lParamSort){
 
 void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRect& rectHL,bool highlighted)
 {
+	/* Don't do any drawing if we not being watched. */
+	if ((theApp.xmuledlg->transferwnd->windowtransferstate) || (theApp.xmuledlg->GetActiveDialog() != 2)) {
+		return;
+	}
+
   if(highlighted) {
     if(GetFocus()) {
       dc->SetBackground(*m_hilightBrush);
@@ -472,6 +481,10 @@ void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRe
     cur_rec.right=rect.x+rect.width;
     cur_rec.bottom=rect.y+rect.height;
     
+    // lagloose
+    CString rbuffer;
+    // end lagloose
+
     CString Sbuffer;
     CKnownFile* file = theApp.sharedfiles->GetFileByID(client->reqfileid);
     //CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
@@ -519,6 +532,11 @@ void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRe
 		image = 0;
 	    }
 	  }
+	  
+	  // Added Thief icon [BlackRat]
+	  if(client->thief) 
+		  image = 9;
+						
 	  POINT point = {cur_rec.left, cur_rec.top+1};
 	  imagelist.Draw(image,*dc,cur_rec.left,cur_rec.top+1,wxIMAGELIST_DRAW_TRANSPARENT);
 	  //imagelist.Draw(dc,image, point, ILD_NORMAL);
@@ -536,9 +554,8 @@ void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRe
 	    Sbuffer = "?";
 	  break;
 	case 2:
-		// lagloose -- Enhanced upload stats
+		// lagloose
 		if (client->GetDownloadState() == DS_DOWNLOADING) {
-			CString rbuffer;
 			Sbuffer = "";
 			rbuffer.Format("%.1f",(float)client->GetDatarate()/1024);
 			Sbuffer.Append(rbuffer);
@@ -570,7 +587,7 @@ void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRe
 	    Sbuffer = GetResString(IDS_CONNVIASERVER);
 	    break;
 	  case US_UPLOADING:
-	    // lagloose -- Enhanced upload stats
+	    // lagloose
 	    Sbuffer = "<-- ";
 	    Sbuffer.Append(GetResString(IDS_TRANSFERRING));
 	    if (client->GetDownloadState() == DS_DOWNLOADING) {
@@ -608,9 +625,10 @@ void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRe
 	  }
 	  break;
 	}
-	if( iColumn != 7 && iColumn != 0 )
+	if( iColumn != 7 && iColumn != 0 ) {
 	  //dc->DrawText(Sbuffer,Sbuffer.GetLength(),&cur_rec,DT_LEFT|DT_SINGLELINE|DT_VCENTER|DT_NOPREFIX|DT_END_ELLIPSIS);
 	  dc->DrawText(Sbuffer,cur_rec.left,cur_rec.top+3);
+	}
 	cur_rec.left += cx;//GetColumnWidth(iColumn);
 	delete clipper;
       }
