@@ -22,6 +22,7 @@
 #include "xmule.h"
 #include "KnownFile.h"
 #include "ListenSocket.h"
+#include <string.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include "ini2.h"
@@ -88,8 +89,11 @@ void CUploadQueue::AddUpNextClient(CUpDownClient* directadd){
 				if (!cur_client->socket)
 					cur_client->Disconnected();
 			}
+			// Banned client or suspended upload ? 
+			else if (cur_client->IsBanned() || suspended_uploads_list.Find(cur_client->reqfileid)) 
+			        continue;
 			// finished clearing
-			else if ( (cur_client->GetScore(true) > bestscore) && (!cur_client->IsBanned()) 
+			else if ( (cur_client->GetScore(true) > bestscore) 
 				&& (!cur_client->HasLowID() || (cur_client->socket && cur_client->socket->IsConnected()) ) ){
 				bestscore = cur_client->GetScore(true);
 				toadd = pos2;
@@ -101,8 +105,102 @@ void CUploadQueue::AddUpNextClient(CUpDownClient* directadd){
 		RemoveFromWaitingQueue(toadd, true);
 		theApp.xmuledlg->transferwnd->ShowQueueCount(waitinglist.GetCount());
 	}
-	else
-		newclient = directadd;
+	else {
+		//prevent another potential access of a suspended upload
+		if(suspended_uploads_list.Find(directadd->reqfileid))
+			return;
+		else
+			newclient = directadd;
+	}
+	
+	// Thief clients handling [BlackRat]
+	if (newclient->thief) {
+		// what kind of thief is it ?
+		switch (newclient->leechertype){
+            /* Add log line according to leecher type */
+            case 1 :
+				{
+				   theApp.xmuledlg->AddLogLine(false,"%s [%s:%i] using %s removed : invalide eMule client",newclient->m_pszUsername,newclient->m_szFullUserIP,newclient->m_nUserPort,newclient->m_clientVerString.c_str());
+                   break;
+                }
+			case 2 :
+				{
+				   theApp.xmuledlg->AddLogLine(false,"%s [%s:%i] using %s removed : suspicious mod string change",newclient->m_pszUsername,newclient->m_szFullUserIP,newclient->m_nUserPort,newclient->m_clientVerString.c_str());
+				   break;
+				}
+			case 3 :
+				{
+				   theApp.xmuledlg->AddLogLine(false,"%s [%s:%i] using %s removed : known leecher",newclient->m_pszUsername,newclient->m_szFullUserIP,newclient->m_nUserPort,newclient->m_clientVerString.c_str());
+                   break;
+                }
+			case 4 :
+				{
+				   theApp.xmuledlg->AddLogLine(false,"%s [%s:%i] using %s removed : suspicious hash change",newclient->m_pszUsername,newclient->m_szFullUserIP,newclient->m_nUserPort,newclient->m_clientVerString.c_str());
+				   break;
+			    }
+			case 5 :
+				{
+				   theApp.xmuledlg->AddLogLine(false,"%s [%s:%i] using %s removed : use your own hash",newclient->m_pszUsername,newclient->m_szFullUserIP,newclient->m_nUserPort,newclient->m_clientVerString.c_str());
+				   break;
+				}
+			default :
+				{
+				   theApp.xmuledlg->AddLogLine(false,"%s [%s:%i] using %s removed : suspicious name change",newclient->m_pszUsername,newclient->m_szFullUserIP,newclient->m_nUserPort,newclient->m_clientVerString.c_str());
+				}
+			}
+	    // remove client !
+		theApp.uploadqueue->RemoveFromUploadQueue(newclient,true);
+		return;
+	}
+
+	// Anti-leecher mods and irregular clients [BlackRat - LSD]
+	if (((strcmp(newclient->m_pszUsername,"celinesexy") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"Chief") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"darkmule") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"dodgethis") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"edevil") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"energyfaker") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"eVortex") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"|eVorte|X|") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"$GAM3R$") == 0) ||
+	     (strcmp(newclient->m_pszUsername,"G@m3r") == 0) ||		 
+		 (strcmp(newclient->m_pszUsername,"Leecha") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"Mison") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"phArAo") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"RAMMSTEIN") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"Reverse") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"[toXic]") == 0) ||
+		 (strcmp(newclient->m_pszUsername,"$WAREZ$") == 0) ||
+		 (newclient->m_clientModString.Cmp("aldo") == 0 ) ||
+         (newclient->m_clientModString.Cmp("booster") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("darkmule") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("d-unit") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("DM-") == 0 ) ||       
+		 (newclient->m_clientModString.Cmp("dodgethis") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("Dragon") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("egomule") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("eVortex") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("father") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("Freeza") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("gt mod") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("imperator") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("LegoLas") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("Max") == 0 )  ||
+		 (newclient->m_clientModString.Cmp("Mison") == 0 ) ||
+	     (newclient->m_clientModString.Cmp("SpeedLoad") == 0 ) ||
+		 (newclient->m_clientModString.Cmp("|X|") == 0 ) ||
+		 ((newclient->m_clientModString.IsEmpty() == false) && (newclient->GetClientSoft() != SO_EMULE)) ||
+		 ((!newclient->GetMuleVersion() && (newclient->GetClientSoft()==SO_EMULE || newclient->GetClientSoft()==SO_OLDEMULE)) && (newclient->GetVersion()==60 || !newclient->GetVersion())) ||
+		 (!newclient->ExtProtocolAvailable() && newclient->GetClientSoft()==SO_EMULE && (newclient->GetVersion()==60 || !newclient->GetVersion())) ||
+		 ((newclient->GetVersion()>589) && (newclient->GetSourceExchangeVersion()>0) && (newclient->GetClientSoft()== SO_EDONKEY)))	 	 
+	   )
+	{		
+		// thief !
+		 newclient->thief=true;
+		 theApp.uploadqueue->RemoveFromUploadQueue(newclient,true);
+		 theApp.xmuledlg->AddLogLine(false,"%s [%s:%i] using %s removed : leecher, invalid eMule or irregular Donkey",newclient->GetUserName(),newclient->GetFullIP(),newclient->GetUserPort(),newclient->GetClientVerString().c_str());
+		 return;
+	}	
 
 	if (IsDownloading(newclient)){
 		return;
@@ -223,8 +321,10 @@ void CUploadQueue::AddUpNextClient(CUpDownClient* directadd){
 					cur_client->Disconnected();
 			}
 			// finished clearing
-			else if ( (cur_client->GetScore(true) > bestscore) && (!cur_client->IsBanned()) 
-				&& (!cur_client->HasLowID() || (cur_client->socket && cur_client->socket->IsConnected()) ) ){
+			// FooMan: Additional restriction added to prevent upload of files on suspended_uploads_list
+			else if ( ( (cur_client->GetScore(true) > bestscore) && (!cur_client->IsBanned()) 
+				&& (!cur_client->HasLowID() || (cur_client->socket && cur_client->socket->IsConnected()) ) )
+				&& (!suspended_uploads_list.Find(cur_client->reqfileid) ) ){
 				bestscore = cur_client->GetScore(true);
 				toadd = pos2;
 			}
@@ -627,10 +727,10 @@ void TimerProc() {
 			CIni ini( fullpath, "xMule" );
 			delete[] fullpath;
 
-			buffer.Format("%I64Lu",theApp.stat_sessionReceivedBytes+theApp.glob_prefs->GetTotalDownloaded());
+			buffer.Format("%llu",theApp.stat_sessionReceivedBytes+theApp.glob_prefs->GetTotalDownloaded());
 			ini.WriteString("TotalDownloadedBytes",buffer ,"Statistics");
 
-			buffer.Format("%I64Lu",theApp.stat_sessionSentBytes+theApp.glob_prefs->GetTotalUploaded());
+			buffer.Format("%llu",theApp.stat_sessionSentBytes+theApp.glob_prefs->GetTotalUploaded());
 			ini.WriteString("TotalUploadedBytes",buffer ,"Statistics");
 		}
 	}
@@ -670,3 +770,45 @@ void CUploadQueue::FindSourcesForFileById(CTypedPtrList<CPtrList, CUpDownClient*
 			srclist->AddTail(potential);
 	}
 }
+
+/*
+ * This function adds a file indicated by filehash to suspended_uploads_list
+ */
+void CUploadQueue::SuspendUpload( const CFileHash& filehash )
+{
+	//Append the filehash to the list.
+	suspended_uploads_list.Append(filehash);
+	CString base16hash = EncodeBase16(filehash, 16);
+	
+	printf("%s: Suspending uploads of file.\n", base16hash.GetBuffer());
+	
+	POSITION pos = uploadinglist.GetHeadPosition();
+	while(pos) { //while we have a valid position
+		CUpDownClient *potential = uploadinglist.GetNext(pos);
+		//check if the client is uploading the file we need to suspend
+		if(memcmp(potential->reqfileid, filehash, 16) == 0) {
+			//remove the unlucky client from the upload queue and add to the waiting queue
+			RemoveFromUploadQueue(potential, 1);
+			printf("%s: Removed user '%s'\n", base16hash.GetBuffer() ,potential->GetUserName() );
+			//this code to add to the waitinglist was copied from the end of AddClientToQueue()
+			//the function itself is not used as it could prevent the requeuing of the client
+			waitinglist.AddTail(potential);
+			potential->SetUploadState(US_ONUPLOADQUEUE);
+			potential->SendRankingInfo();
+			theApp.xmuledlg->transferwnd->queuelistctrl->AddClient(potential);
+			theApp.xmuledlg->transferwnd->ShowQueueCount(waitinglist.GetCount());
+			printf("%s: ReQueued user '%s'\n", base16hash.GetBuffer(), potential->GetUserName() );
+		}
+	}
+}
+
+/*
+ * This function removes a file indicated by filehash from suspended_uploads_list.
+ */
+void CUploadQueue::ResumeUpload( const CFileHash& filehash )
+{
+	//Find the position of the filehash in the list and remove it.
+	suspended_uploads_list.RemoveAt( suspended_uploads_list.Find(filehash) );
+	printf("%s: Resuming uploads of file.\n", EncodeBase16(filehash, 16).GetBuffer() );
+	
+}
