@@ -246,6 +246,42 @@ void CWebServer::ProcessImgFileReq(ThreadData Data) {
 	#endif
 }
 
+void CWebServer::ProcessStyleFileReq(ThreadData Data) {
+	wxString filename=Data.sURL;
+	wxString contenttype;
+
+	printf("inc. fname=%s\n",filename.GetData());
+	contenttype="Content-Type: text/css\r\n";
+
+
+	filename=filename.Right(filename.Length()-1);
+	//filename.Replace("/","\\");
+	filename=wxString(theApp.glob_prefs->GetAppDir())+"webserver/"+filename;
+	printf("**** cssrequest: %s\n",filename.GetData());
+	wxFileInputStream* fis = new wxFileInputStream(filename);
+	if(fis->Ok()) {
+	  fis->SeekI(0,wxFromEnd);
+	  off_t koko=fis->TellI();
+	  fis->SeekI(0,wxFromStart);
+	  char* buffer=new char[koko];
+	  fis->Read((void*)buffer,koko);
+	  Data.pSocket->SendContent((char*)contenttype.GetData(),(void*)buffer,fis->LastRead());
+	  delete fis;
+	  delete buffer;
+	}
+	#if 0
+	CFile file;
+	if(file.Open(filename, CFile::modeRead|CFile::typeBinary))
+	{
+		char* buffer=new char[file.GetLength()];
+		int size=file.Read(buffer,file.GetLength());
+		file.Close();
+		Data.pSocket->SendContent(contenttype, buffer, size);
+		delete[] buffer;
+	}
+	#endif
+}
+
 
 void CWebServer::ProcessURL(ThreadData Data)
 {
