@@ -40,7 +40,8 @@ void CWebSocket::OnRequestReceived(char* pHeader, DWORD dwHeaderLen, char* pData
  	wxString sHeader(pHeader, dwHeaderLen);
 	wxString sData(pData, dwDataLen);
 	wxString sURL;
-	bool filereq=false;
+	bool imgreq=false;
+	bool stylereq=false;
 
 	if(sHeader.Left(3) == "GET")
 		sURL = sHeader.Trim();
@@ -55,15 +56,21 @@ void CWebSocket::OnRequestReceived(char* pHeader, DWORD dwHeaderLen, char* pData
 
 	if (sURL.Length()>4 && sURL.Right(4).MakeLower()==".gif" || sURL.Right(4).MakeLower()==".jpg" || sURL.Right(4).MakeLower()==".png" ||
 		sURL.Right(4).MakeLower()==".bmp" ||sURL.Right(5).MakeLower()==".jpeg")
-		filereq=true;
+		imgreq=true;
+	if (sURL.Length()>4 && sURL.Right(4).MakeLower()==".css")
+		stylereq=true;
 
 	ThreadData Data;
 	Data.sURL = sURL;
 	Data.pThis = m_pParent;
 	Data.pSocket = this;
 
-	if (!filereq) m_pParent->ProcessURL(Data);
-		else m_pParent->ProcessImgFileReq(Data);
+	if (!imgreq && !stylereq) 
+		m_pParent->ProcessURL(Data);
+	else if (!imgreq)
+		m_pParent->ProcessStyleFileReq(Data);
+	else
+		m_pParent->ProcessImgFileReq(Data);
 
 	Disconnect();    	
 }
@@ -461,7 +468,7 @@ exit_select:
     //VERIFY(!closesocket(hSocket));
     close(hSocket);
 
-    printf("*** hanska: exited\n");
+    printf("*** hanska: exited (WebSocket closed)\n");
     return 0;
 }
 
@@ -474,8 +481,9 @@ void* WebSocketListeningFunc(void *pThis)
         struct sockaddr_in stAddr;
 
         stAddr.sin_family = AF_INET;
-        stAddr.sin_port = htons(/*theApp.glob_prefs->GetWSPort()*/8080);
-#warning web server port is missing
+        stAddr.sin_port = htons(theApp.glob_prefs->GetWSPort());
+	printf("*** WebServer: Using port: %i\n",
+			theApp.glob_prefs->GetWSPort());
 
         stAddr.sin_addr.s_addr = INADDR_ANY;
 
