@@ -88,8 +88,6 @@ enum {
   LAST_SIGNAL
 }; 
 
-static guint plug_signals[LAST_SIGNAL] = { 0 };
-
 GtkType
 gtk_plug_xembed_get_type ()
 {
@@ -118,7 +116,6 @@ gtk_plug_xembed_get_type ()
 static void
 gtk_plug_xembed_class_init (GtkPlugXEmbedClass *class)
 {
-  GtkObjectClass *gtk_object_class = (GtkObjectClass *)class;
   GtkWidgetClass *widget_class = (GtkWidgetClass *)class;
   GtkWindowClass *window_class = (GtkWindowClass *)class;
   GtkContainerClass *container_class = (GtkContainerClass *)class;
@@ -153,6 +150,9 @@ gtk_plug_xembed_class_init (GtkPlugXEmbedClass *class)
   window_class->keys_changed = gtk_plug_xembed_keys_changed;
 #endif
 
+#if SIGNAL_ENABLED
+ // for some reason, this _will_ segfault
+ // so I removed it. it is not needed anyway
   plug_signals[EMBEDDED] =
 	  gtk_signal_new ("embedded",
 			  GTK_RUN_LAST,
@@ -160,6 +160,7 @@ gtk_plug_xembed_class_init (GtkPlugXEmbedClass *class)
 			  GTK_STRUCT_OFFSET (GtkPlugXEmbedClass, embedded),
 			  gtk_marshal_NONE__NONE,
 			  GTK_TYPE_NONE, 0);
+#endif
 }
 
 static void
@@ -363,9 +364,10 @@ gtk_plug_xembed_construct (GtkPlugXEmbed         *plug,
 	      plug->socket_window = NULL;
 	    }
 	}
-
+#if SIGNAL_ENABLED
       if (plug->socket_window)
 	g_signal_emit (G_OBJECT (plug), plug_signals[EMBEDDED], 0);
+#endif
 #else
       plug->socket_window = gdk_window_foreign_new (socket_id);
 #endif
@@ -404,20 +406,6 @@ gtk_plug_xembed_get_id (GtkPlugXEmbed *plug)
   return GDK_WINDOW_XWINDOW (GTK_WIDGET (plug)->window);
 }
 
-static void
-gtk_plug_xembed_finalize (GtkObject *object)
-{
-  GtkPlugXEmbed *plug = GTK_PLUG_XEMBED (object);
-
-  if (plug->grabbed_keys)
-    {
-      g_hash_table_destroy (plug->grabbed_keys);
-      plug->grabbed_keys = NULL;
-    }
-  
-  //GTK_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
 static void
 gtk_plug_xembed_unrealize (GtkWidget *widget)
 {
@@ -1169,10 +1157,12 @@ gtk_plug_xembed_filter_func (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer da
 	      g_hash_table_foreach (plug->grabbed_keys, add_grabbed_key_always, plug);
 #endif
 
+#if SIGNAL_ENABLED
 	    if (!was_embedded)
 	      gtk_signal_emit (GTK_OBJECT (plug), plug_signals[EMBEDDED], 0);
-	  }
+#endif
 
+	  }
       done:
 	gtk_object_unref (GTK_OBJECT(plug));
 	
