@@ -623,8 +623,7 @@ void mmMultiButton::SetDefaultBitmap(wxBitmap& bm)
   Refresh();
 } // SetDefaultBitmap
 
-void mmMultiButton::SetDefaultBitmap(wxBitmap bm)
-{
+void mmMultiButton::SetDefaultBitmap_noref(wxBitmap bm) {
   mMyBitmap=bm;
   mDefaultBitmap = &mMyBitmap;
   Refresh();
