@@ -23,6 +23,8 @@
 #endif
 #define WM_APP 5500
 
+#define MOD_VERSION             "xMule"
+#define ET_MOD_VERSION 			0x55
 // MOD Note: Do not change this part - Merkur
 #define CURRENT_VERSION_SHORT	0x26
 #define CURRENT_VERSION_CHECK	0x26D
@@ -203,6 +205,7 @@
 #define FT_SOURCES				0x15
 #define FT_PERMISSIONS			0x16
 #define FT_ULPRIORITY			0x17
+#define FT_CATEGORY 			0x53
 
 // statistic
 #define FT_ATTRANSFERED			0x50
@@ -212,6 +215,7 @@
 #define CT_NAME					0x01
 #define CT_VERSION				0x11
 #define	CT_PORT					0x0f
+#define CT_FRIENDSHARING			0x66
 
 #define MP_MESSAGE				10102
 #define MP_DETAIL				10103
@@ -253,7 +257,10 @@
 #define MP_REMOVEFROMSTATIC		10400
 #define MP_VIEWFILECOMMENTS		10401
 #define MP_VERSIONCHECK			10402
-#define MP_WEBURL				10500
+#define MP_WEBURL			10500
+#define MP_CAT_ADD			10321
+#define MP_CAT_EDIT			10322
+#define MP_CAT_REMOVE			10323
 
 // reserve some for weburls!
 
@@ -272,6 +279,13 @@
 #define Irc_AddFriend			10328
 #define	Irc_SendLink			10329
 #define Irc_SetSendLink			10330
+
+#define MP_ASSIGNCAT				10700
+// reserve some for categories!
+#define MP_SCHACTIONS				10800
+// reserve some for schedules
+#define MP_CAT_SET0				10900
+// reserve some for change all-cats (about 20)
 	
 // xmule tagnames
 #define ET_COMPRESSION			0x20
@@ -281,6 +295,29 @@
 #define ET_COMMENTS				0x24
 #define ET_EXTENDEDREQUEST		0x25
 #define ET_COMPATABLECLIENT		0x26
+#define ET_FEATURES			0x27	// bit 0: SecIdent v1
+						// bit 1: SecIdent v2
+
+// tags by various mods	
+#define ET_TAROD			0x77	// int - flag - Tarod mod
+#define ET_TAROD_VERSION		0x78	// Tarod mod version number
+#define ET_L2HAC			0x3E	// does send FILEREASKTIME
+	// seems to synchronize connecting between low and high ID users
+#define ET_MOD_LSD			0x87	// int - flag
+#define ET_MOD_LSD_VERSION		0x88	// int
+#define ET_MOD_SECURE_COMMUNITY		0x5C	// string
+#define ET_MOD_PROTOCOL			0x56	// string
+#define ET_MOD_Morph			0x79	// int
+#define ET_MOD_Morph_VERSION		0x80	// int
+#define ET_MOD_FUSION			0x66	// int
+#define ET_MOD_FUSION_VERSION		0x67	// string
+#define ET_MOD_MorTillo			0x82	// int
+#define ET_MOD_MorTillo_VERSION		0x83	// string
+#define ET_MOD_LOVELACE_VERSION		0x90	// string
+#define ET_MOD_OXY			0x94	// unspecified type
+#define ET_PLUS				0x99	// int - eMule Plus version
+#define ET_FEATURESET			0x54	// int - [Bloodymad Featureset]
+
 
 // xmuleapp <-> xmuleapp
 #define OP_ED2KLINK				12000
@@ -335,4 +372,25 @@
 #define MP_LISTCOL_13			10613
 #define MP_LISTCOL_14			10614
 #define MP_LISTCOL_15			10615
+
+  /* Razor 1a - Modif by MikaelB
+     Opcodes for :
+      - Drop No Needed Sources now
+      - Drop Full Queue Sources now
+      - Drop High Queue Rating Sources now
+      - Clean Up Sources now ( drop NNS, FQS and HQRS )
+      - Swap every A4AF to this file now
+      - Swap every A4AF to this file ( AUTO )
+      - Swap every A4AF to any other file now   */
+
+      #define MP_DROP_NO_NEEDED_SOURCES           57841
+      #define MP_DROP_FULL_QUEUE_SOURCES          57842
+      #define MP_DROP_HIGH_QUEUE_RATING_SOURCES   57843
+      #define MP_CLEAN_UP_SOURCES                 57844
+      #define MP_SWAP_A4AF_TO_THIS                57845
+      #define MP_SWAP_A4AF_TO_THIS_AUTO           57846
+      #define MP_SWAP_A4AF_TO_ANY_OTHER           57847
+
+  /* End Modif */
+  
 #endif
