@@ -19,6 +19,7 @@
 #include "wintypes.h"
 #include "otherfunctions.h"
 #include "xmule.h"
+#include <wx/utils.h>
 
 #include "strings.en"
 
@@ -189,7 +190,6 @@ wxString URLEncode(wxString sIn){
     LPBYTE pOutBuf = NULL;
     register LPBYTE pInTmp = NULL;
     LPBYTE pInBuf =(LPBYTE)sIn.GetWriteBuf(nLen); //GetData(); //GetBuffer(nLen);
-    BYTE b = 0;
 	
     //alloc out buffer
     pOutBuf = (LPBYTE)sOut.GetWriteBuf(nLen*3-2); //GetData(); //GetBuffer(nLen  * 3 - 2);//new BYTE [nLen  * 3];
@@ -261,11 +261,6 @@ wxString GetFiletypeByName(wxString infile) {
 }
 
 
-inline char* nstrdup(const char* todup) { 
-   size_t len = strlen(todup)+1; 
-   return (char*)memcpy(new char[len], todup, len); 
-} 
-
 CString MakeStringEscaped(CString in) {
 	in.Replace("&","&&");
 	
@@ -406,7 +401,6 @@ CString EncodeBase32(const unsigned char* buffer, unsigned int bufLen)
     
 	unsigned int i, index;
     unsigned char word;
-	int pos = 0;
 
     for(i = 0, index = 0; i < bufLen;) {
 
@@ -544,6 +538,95 @@ void RunURL(CAbstractFile* file, CString urlpattern)
 	ShellExecute(NULL, NULL, urlpattern, NULL, theApp.glob_prefs->GetAppDir(), SW_SHOWDEFAULT);
 #endif
 }
+CString GetCatTitle(int catid) {
+        switch (catid) {
+                case 0 : return GetResString(IDS_ALL);
+                case 1 : return GetResString(IDS_ALLOTHERS);
+                case 2 : return GetResString(IDS_STATUS_NOTCOMPLETED);
+                case 3 : return GetResString(IDS_DL_TRANSFCOMPL);
+                case 4 : return GetResString(IDS_WAITING);
+                case 5 : return GetResString(IDS_DOWNLOADING);
+                case 6 : return GetResString(IDS_ERRORLIKE);
+                case 7 : return GetResString(IDS_PAUSED);
+                case 8 : return GetResString(IDS_STOPPED);
+                case 9 : return GetResString(IDS_VIDEO);
+                case 10 : return GetResString(IDS_AUDIO);
+                case 11 : return GetResString(IDS_SEARCH_ARC);
+                case 12 : return GetResString(IDS_SEARCH_CDIMG);
+                case 13 : return GetResString(IDS_SEARCH_PICS);
+                case 14 : return GetResString(IDS_TEXT);
+        }
+        return "?";
+}
+  
+bool CheckShowItemInGivenCat(CPartFile* file,int inCategory) {
+        // easy normal cases
+		bool IsInCat;
+		bool IsNotFiltered = true;
+   
+		IsInCat = ((inCategory==0) || (inCategory>0 && inCategory==file->GetCategory()));
+                                                                                
+        if (theApp.glob_prefs->GetAllcatType()>0)
+                switch (theApp.glob_prefs->GetAllcatType()) {
+                        case 1 : {
+							IsNotFiltered = ((file->GetCategory()==0) || (inCategory>0));
+							break;
+						}
+                        case 2 : {
+							IsNotFiltered = (file->IsPartFile());
+							break;
+						}
+                        case 3 : {
+							IsNotFiltered = (!file->IsPartFile());
+							break;
+						}
+                        case 4 : {
+							IsNotFiltered = ((file->GetStatus()==PS_READY|| file->GetStatus()==PS_EMPTY) && file->GetTransferingSrcCount()==0);
+							break;
+						}
+                        case 5 : {
+							IsNotFiltered = ((file->GetStatus()==PS_READY|| file->GetStatus()==PS_EMPTY) && file->GetTransferingSrcCount()>0);
+							break;
+						}
+                        case 6 : {
+							IsNotFiltered = (file->GetStatus()==PS_ERROR);
+							break;
+						}
+                        case 7 : {
+							IsNotFiltered =  ((file->GetStatus()==PS_PAUSED) && (!file->IsStopped()));
+							break;
+						}
+                        case 8 : {
+							IsNotFiltered = file->IsStopped();
+							break;
+						}
+                        case 9 : {
+							IsNotFiltered = file->IsMovie();
+							break;
+						}
+			  			case 10 : {
+							IsNotFiltered = file->IsSound();
+							break;
+						}
+                        case 11 : {
+							IsNotFiltered = file->IsArchive();
+							break;
+						}
+			  			case 12 : {
+							IsNotFiltered = file->IsCDImage();
+							break;
+						}
+			  			case 13 : {
+							IsNotFiltered = file->IsImage();
+							break;
+						}
+			  			case 14 : {
+							IsNotFiltered =  file->IsText();
+							break;
+						}
+                }
+        return (IsNotFiltered && IsInCat);
+}
 
 #ifdef __FreeBSD__   
 long long atoll( char * s ){
@@ -556,3 +639,36 @@ void MakeFoldername(char* path){
 	if (string.Length()>0) if (string.Right(1)=='\\') string=string.Left(string.Length()-1);
 	sprintf(path,"%s",string.GetData());
 }
+
+void HexDump(const void *buffer, unsigned long buflen)
+{
+	const uint8* cbuf = (const uint8*)buffer;
+
+	for ( unsigned long ofs = 0; ofs < buflen; /* no increment here */ )
+	{
+		printf("%08lx", ofs);
+
+		for ( unsigned long i = 0; (i<8) && (ofs<buflen); i++,ofs++ )
+		{
+			printf(" %02x", (int)cbuf[ofs]);
+		}
+		printf("\n");
+	}
+}
+
+bool BackupFile(const wxString& filename, const wxString& appendix)
+{
+	wxRemoveFile(filename + appendix);
+
+	if ( !wxRenameFile(filename, filename + appendix) ) {
+		if ( !wxCopyFile(filename, filename + appendix) ) {
+			printf("info: Could not create backup of '%s'\n",
+			       filename.c_str());
+			return false;
+		} else if ( !wxRemoveFile(filename) ) {
+			printf("info: Could not delete original '%s' after creating backup\n", filename.c_str());
+		}
+	}
+	return true;
+}
+
