@@ -24,38 +24,6 @@
 #define new DEBUG_NEW
 #endif
 
-extern char* nstrdup(char const *mj)
-{
-  if(mj==NULL) {
-    char* empty="";
-    /* this really shouldn't happen */
-    char* uus=new char[1];
-    uus[0]=0;
-    return uus;
-  }
-
-  char *uus=new char[strlen(mj)+1];
-  memset(uus,0,(strlen(mj)+1));
-  strcpy(uus,mj);
-  return uus;
-}
-
-extern char* nstrdup(char *mj)
-{
-  if(mj==NULL) {
-    char* empty="";
-    /* this really shouldn't happen */
-    char* uus=new char[1];
-    uus[0]=0;
-    return uus;
-  }
-
-  char *uus=new char[strlen(mj)+1];
-  memset(uus,0,(strlen(mj)+1));
-  strcpy(uus,mj);
-  return uus;
-}
-
 Packet::Packet(uint8 protocol){
 	m_bSplitted = false;
 	m_bLastSplitted = false;
@@ -228,14 +196,14 @@ CTag::CTag(char* name,uint32 intvalue){
 	tag = new Tag_Struct;
 	memset(tag,0,sizeof(Tag_Struct));
 	tag->tagname = nstrdup(name);
-	tag->type = 3;
+	tag->type = TAG_INTEGER;
 	tag->intvalue = intvalue;
 }
 
 CTag::CTag(int8 special, uint32 intvalue){
 	tag = new Tag_Struct;
 	memset(tag,0,sizeof(Tag_Struct));
-	tag->type = 3;
+	tag->type = TAG_INTEGER;
 	tag->intvalue = intvalue;
 	tag->specialtag = special;
 }
@@ -244,14 +212,14 @@ CTag::CTag(char* name,char* strvalue){
 	tag = new Tag_Struct;
 	memset(tag,0,sizeof(Tag_Struct));
 	tag->tagname = nstrdup(name);
-	tag->type = 2;
+	tag->type = TAG_STRING;
 	tag->stringvalue = nstrdup(strvalue);
 }
 
 CTag::CTag(int8 special, char* strvalue){
 	tag = new Tag_Struct;
 	memset(tag,0,sizeof(Tag_Struct));
-	tag->type = 2;
+	tag->type = TAG_STRING;
 	tag->stringvalue = nstrdup(strvalue);
 	tag->specialtag = special;
 }
@@ -269,70 +237,103 @@ CTag::CTag(Tag_Struct* in_tag){
 CTag::CTag(CFile* in_data){
   tag = new Tag_Struct;
   memset(tag,0,sizeof(Tag_Struct));
-  in_data->Read(&tag->type,1);
+  if ( 1 != in_data->Read(&tag->type,1) )
+  	throw CInvalidPacket("short packet reading tag data type");
   uint16 length;
-  in_data->Read(&length,2);
-  if (length == 1)
-    in_data->Read(&tag->specialtag,1);
+  if ( 2 != in_data->Read(&length,2) )
+  	throw CInvalidPacket("short packet reading tagname length");
+  if (length == 1) {
+    if ( 1 != in_data->Read(&tag->specialtag,1) )
+  	throw CInvalidPacket("short packet reading tag id");
+  }
   else {
     tag->tagname = new char[length+1];
-    in_data->Read(tag->tagname,length);
+    if ( length != in_data->Read(tag->tagname,length) )
+  	throw CInvalidPacket("short packet reading tagname");
     tag->tagname[length] = 0;
   }
-  if (tag->type == 2){
-    in_data->Read(&length,2);
+  if ((TTagType)tag->type == TAG_STRING){
+    if ( 2 != in_data->Read(&length,2) )
+  	throw CInvalidPacket("short packet reading string data length");
     tag->stringvalue = new char[length+1];
-    in_data->Read(tag->stringvalue,length);
+    if ( length != in_data->Read(tag->stringvalue,length) )
+  	throw CInvalidPacket("short packet reading string data");
     tag->stringvalue[length] = 0;
   }
-  else if (tag->type == 3)
-    in_data->Read(&tag->intvalue,4);
+  else if ((TTagType)tag->type == TAG_INTEGER) {
+    if ( 4 != in_data->Read(&tag->intvalue,4) )
+  	throw CInvalidPacket("short packet reading integer data");
+  }
+  else
+  	throw CStrangePacket("invalid tag data type");
 }
 
 CTag::CTag(CMemFile* in_data){
   tag = new Tag_Struct;
   memset(tag,0,sizeof(Tag_Struct));
-  in_data->Read(&tag->type,1);
+  if ( 1 != in_data->Read(&tag->type,1) )
+  	throw CInvalidPacket("short packet reading tag data type");
   uint16 length;
-  in_data->Read(&length,2);
-  if (length == 1)
-    in_data->Read(&tag->specialtag,1);
+  if ( 2 != in_data->Read(&length,2) )
+  	throw CInvalidPacket("short packet reading tagname length");
+  if (length == 1) {
+    if ( 1 != in_data->Read(&tag->specialtag,1) )
+  	throw CInvalidPacket("short packet reading tag id");
+  }
   else {
     tag->tagname = new char[length+1];
-    in_data->Read(tag->tagname,length);
+    if ( length != in_data->Read(tag->tagname,length) )
+  	throw CInvalidPacket("short packet reading tagname");
     tag->tagname[length] = 0;
   }
-  if (tag->type == 2){
-    in_data->Read(&length,2);
+  if ((TTagType)tag->type == TAG_STRING){
+    if ( 2 != in_data->Read(&length,2) )
+  	throw CInvalidPacket("short packet reading string data length");
     tag->stringvalue = new char[length+1];
-    in_data->Read(tag->stringvalue,length);
+    if ( length != in_data->Read(tag->stringvalue,length) )
+  	throw CInvalidPacket("short packet reading string data");
     tag->stringvalue[length] = 0;
   }
-  else if (tag->type == 3)
-    in_data->Read(&tag->intvalue,4);
+  else if ((TTagType)tag->type == TAG_INTEGER) {
+    if ( 4 != in_data->Read(&tag->intvalue,4) )
+  	throw CInvalidPacket("short packet reading integer data");
+  }
+  else
+  	throw CInvalidPacket("unknown tag data type");
 }
 
 CTag::CTag(FILE* in_data){
 	tag = new Tag_Struct;
 	memset(tag,0,sizeof(Tag_Struct));
-	fread(&tag->type,1,1,in_data);
+	if ( 1 != fread(&tag->type,1,1,in_data) )
+  		throw CInvalidPacket("short packet reading tag data type");
 	uint16 length;
-	fread(&length,2,1,in_data);
-	if (length == 1)
-		fread(&tag->specialtag,1,1,in_data);
+	if ( 1 != fread(&length,2,1,in_data) )
+  		throw CInvalidPacket("short packet reading tagname length");
+	if (length == 1) {
+		if ( 1 != fread(&tag->specialtag,1,1,in_data) )
+  			throw CInvalidPacket("short packet reading tag id");
+	}
 	else {
 		tag->tagname = new char[length+1];
-		fread(tag->tagname,length,1,in_data);
+		if ( 1 != fread(tag->tagname,length,1,in_data) )
+  			throw CInvalidPacket("short packet reading tagname");
 		tag->tagname[length] = 0;
 	}
-	if (tag->type == 2){
-		fread(&length,2,1,in_data);
+	if ((TTagType)tag->type == TAG_STRING){
+		if ( 1 != fread(&length,2,1,in_data) )
+  			throw CInvalidPacket("short packet reading string data length");
 		tag->stringvalue = new char[length+1];
-		fread(tag->stringvalue,length,1,in_data);
+		if ( 1 != fread(tag->stringvalue,length,1,in_data) )
+  			throw CInvalidPacket("short packet reading string data");
 		tag->stringvalue[length] = 0;
 	}
-	else if (tag->type == 3)
-		fread(&tag->intvalue,4,1,in_data);
+	else if ((TTagType)tag->type == TAG_INTEGER) {
+		if ( 1 != fread(&tag->intvalue,4,1,in_data) )
+  			throw CInvalidPacket("short packet reading integer data");
+	}
+  	else
+  		throw CInvalidPacket("unknown tag data type");
 }
 
 CTag::~CTag(){
@@ -355,12 +356,12 @@ bool CTag::WriteTagToFile(CFile* file){
 		file->Write(&taglen,2);
 		file->Write(&tag->specialtag,taglen);
 	}
-	if (tag->type == 2){
+	if ((TTagType)tag->type == TAG_STRING){
 		uint16 len = (uint16)strlen(tag->stringvalue);
 		file->Write(&len,2);
 		file->Write(tag->stringvalue,len);
 	}
-	else if (tag->type == 3)
+	else if ((TTagType)tag->type == TAG_INTEGER)
 		file->Write(&tag->intvalue,4);
 	return true;
 }
@@ -377,12 +378,12 @@ bool CTag::WriteTagToFile(CMemFile* file){
 		file->Write(&taglen,2);
 		file->Write(&tag->specialtag,taglen);
 	}
-	if (tag->type == 2){
+	if ((TTagType)tag->type == TAG_STRING){
 		uint16 len = (uint16)strlen(tag->stringvalue);
 		file->Write(&len,2);
 		file->Write(tag->stringvalue,len);
 	}
-	else if (tag->type == 3)
+	else if ((TTagType)tag->type == TAG_INTEGER)
 		file->Write(&tag->intvalue,4);
 	return true;
 }
@@ -399,12 +400,54 @@ bool CTag::WriteTagToFile(FILE* file){
 		fwrite(&taglen,2,1,file);
 		fwrite(&tag->specialtag,taglen,1,file);
 	}
-	if (tag->type == 2){
+	if ((TTagType)tag->type == TAG_STRING){
 		uint16 len = (uint16)strlen(tag->stringvalue);
 		fwrite(&len,2,1,file);
 		fwrite(tag->stringvalue,len,1,file);
 	}
-	else if (tag->type == 3)
+	else if ((TTagType)tag->type == TAG_INTEGER)
 		fwrite(&tag->intvalue,4,1,file);
 	return ferror(file);
 }
+
+void CTag::DumpToStdout() const
+{
+	if ( tag->tagname )
+		printf("name='%s'", tag->tagname);
+	else
+		printf("special=%u", (unsigned int)tag->specialtag);
+
+	switch ( (TTagType)tag->type )
+	{
+	case TAG_STRING:
+		printf(" string='%s'\n", tag->stringvalue);
+		break;
+	case TAG_INTEGER:
+		printf(" integer=%u\n", (unsigned int)tag->intvalue);
+		break;
+	default:
+		printf(" unknown type %u\n", (unsigned int)tag->type);
+		break;
+	}
+}
+
+TTagType CTag::GetType() const
+{
+	return (TTagType)tag->type;
+}
+
+CInvalidPacket::CInvalidPacket(const char* reason)
+{
+	if ( reason )
+	{
+		strncpy(m_acWhat, reason, sizeof m_acWhat);
+		m_acWhat[sizeof m_acWhat - 1] = 0;
+	}
+	else
+		strcpy(m_acWhat, "(NULL)");
+}
+
+const char* CInvalidPacket::what() const throw()
+{
+	return m_acWhat;
+}
