@@ -1037,6 +1037,8 @@
 #define IDS_SOFTFILES                   1003
 #define IDS_HARDFILES                   1004
 #define IDS_FILTER                      1005
+#define IDS_CHANGECATVIEW               1025
+#define IDS_STATUS_NOTCOMPLETED         1026
 #define IDC_ANIMATE1                    2000
 #define IDC_STATUS                      2001
 #define IDC_FILESTATUS                  2002
@@ -1718,7 +1720,52 @@
 #define IDD_WIZ1_END                    2444
 #define IDC_STATIC_FILTER               2445
 #define IDC_LAST_SEEN_LABEL             2446
+#define IDS_CONFIRMATION		2447
+#define IDS_CATEGORY_DELETE		2448
+#define IDS_TEXT			2449
+#define IDS_OUT_OF_SPACE		2450
 
+/* Razor 1a - Modif by MikaelB */
+#define IDS_DROP_NO_NEEDED_SOURCES           5721
+#define IDS_DROP_FULL_QUEUE_SOURCES          5722
+#define IDS_DROP_HIGH_QUEUE_RATING_SOURCES   5723
+#define IDS_CLEAN_UP_SOURCES                 5724
+#define IDS_SWAP_A4AF_TO_THIS                5725
+#define IDS_SWAP_A4AF_TO_THIS_AUTO           5726
+#define IDS_SWAP_A4AF_TO_ANY_OTHER           5727
+#define IDS_EXTENDED                         5728
+/* End modif */
+  
+#define IDD_PPG_SOURCES_DROPPING 12743
+#define IDD_PPG_GUI_TWEAKS 12744
+#define IDC_ENABLE_AUTO_NNS 12745
+#define IDC_AUTO_NNS_TIMER_TEXT 12746
+#define IDC_AUTO_NNS_TIMER 12747
+#define IDC_AUTO_NNS_TIMER_HELP 12748
+#define IDC_ENABLE_AUTO_FQS 12749
+#define IDC_AUTO_FQS_TIMER_TEXT 12750
+#define IDC_AUTO_FQS_TIMER 12751
+#define IDC_AUTO_FQS_TIMER_HELP 12752
+#define IDC_ENABLE_AUTO_HQRS 12753
+#define IDC_AUTO_HQRS_TIMER_TEXT 12754
+#define IDC_AUTO_HQRS_TIMER 12755
+#define IDC_AUTO_HQRS_TIMER_HELP 12756
+#define IDC_AUTO_HQRS_HQR_TEXT 12757
+#define IDC_AUTO_HQRS_HQR 12758
+#define IDC_AUTO_HQRS_HQR_HELP 12759
+#define IDC_ENABLE_DYNUPLOAD 10002
+#define IDC_PING_URL 10003
+#define IDC_RESPONSE_VALUE 10004
+#define IDC_PING_RADIO 10005
+#define IDC_SELECTED_THEME 10006
+#define IDC_USE_FONT 10007
+#define IDC_SELECTED_FONT 10008
+#define IDC_FONT_BUTTON 10009
+#define IDC_PREVIEW_THEME 10010
+#define IDC_APPLY_THEME 10011
+#define IDC_ENABLE_AUTO_ARRANGING 10012
+#define IDC_ARRANGE_CHOICE 10013
+		
 // Next default values for new objects
 // 
 #ifdef APSTUDIO_INVOKED
