@@ -45,24 +45,24 @@
 #include "WebServer.h"
 //#include <afxmt.h>
 
+//extern CxmuleApp theApp;
+#define theApp (*((CxmuleApp*)wxTheApp))
+#define G_BLEND(a,b) ( ((int)a*b)/100>255?255:((int)a*b)/100 ) 
+
 class CSearchList;
 class CUploadQueue;
 class CListenSocket;
 class CDownloadQueue;
 class CSharedFileList;
 
-#define G_BLEND(a,b) ( ((int)a*b)/100>255?255:((int)a*b)/100 ) 
-
-class CxmuleApp : public wxApp
-{
+class CxmuleApp : public wxApp {
 public:
+				CxmuleApp();
+	virtual		~CxmuleApp();
+	int			OnExit();
+	void			OnFatalException();
 
-	CxmuleApp();
-	virtual ~CxmuleApp();
-	int OnExit();
-	void OnFatalException();
-
-	CxmuleDlg*			xmuledlg;
+	CxmuleDlg*		xmuledlg;
 	CClientList*		clientlist;
 	CKnownFileList*		knownfiles;
 	CPreferences*		glob_prefs;
@@ -74,51 +74,46 @@ public:
 	CUploadQueue*		uploadqueue;
 	CDownloadQueue*		downloadqueue;
 	CClientCreditsList*	clientcredits;
-	CClientUDPSocket*       clientudp;
+	CClientUDPSocket*	clientudp;
 	CFriendList*		friendlist;
-	CWebServer*             webserver;
-	wxMutex				hashing_mut;
-	wxMutex pendingMutex;
+	CWebServer*		webserver;
 	//virtual BOOL		InitInstance();
 	virtual bool 		OnInit();
-	wxString*			pendinglink;
+	wxString*		pendinglink;
 	//tagCOPYDATASTRUCT  sendstruct; //added by Cax2 28/10/02 
-	CIPFilter*			ipfilter;
+	CIPFilter*		ipfilter;
 
-	uint64				stat_sessionReceivedBytes;
-	uint64				stat_sessionSentBytes;
-	uint16				stat_reconnects;
-	DWORD				stat_transferStarttime;
-	DWORD				stat_serverConnectTime;
-	uint16				stat_filteredclients;
-	DWORD				Start_time;
+	uint64			stat_sessionReceivedBytes;
+	uint64			stat_sessionSentBytes;
+	uint16			stat_reconnects;
+	DWORD			stat_transferStarttime;
+	DWORD			stat_serverConnectTime;
+	uint16			stat_filteredclients;
+	DWORD			Start_time;
 
-// Implementierung
+	// Implementierung
 	// ed2k link functions
 	wxString		StripInvalidFilenameChars(wxString strText, bool bKeepSpaces = true);
 	wxString		CreateED2kLink( CAbstractFile* f );
 	wxString		CreateHTMLED2kLink( CAbstractFile* f );
-        wxString         CreateED2kSourceLink( CAbstractFile* f );
-	bool		CopyTextToClipboard( wxString strText );
-	void		OnlineSig(); 
-	void		UpdateReceivedBytes(int32 bytesToAdd);
-	void		UpdateSentBytes(int32 bytesToAdd);
+	wxString		CreateED2kSourceLink( CAbstractFile* f );
+	bool			CopyTextToClipboard( wxString strText );
+	void			OnlineSig(bool zero = false); 
+	void			UpdateReceivedBytes(int32 bytesToAdd);
+	void			UpdateSentBytes(int32 bytesToAdd);
 
 	//DECLARE_MESSAGE_MAP()
 protected:
-	bool ProcessCommandline();
-	void SetTimeOnTransfer();
+	
+	bool 			ProcessCommandline();
+	void 			SetTimeOnTransfer();
 
-	wxLocale m_locale;
+	wxLocale		m_locale;
 
 };
-//extern CxmuleApp theApp;
-#define theApp (*((CxmuleApp*)wxTheApp))
-
-//#include <dmalloc.h>
 
 // helper
-wxColour GetColour(wxSystemColour what);
+wxColour 			GetColour(wxSystemColour what);
 
 
 #endif
