@@ -37,6 +37,7 @@
 //#include "mmsystem.h"
 //#include "EnBitmap.h"
 #include "config.h"
+#include "AddFileThread.h"
 
 #include "mmMultiButton.h"
 #include "muuli_wdr.h"
@@ -84,22 +85,9 @@ BEGIN_EVENT_TABLE(CxmuleDlg,wxFrame)
   EVT_MENU(TM_FINISHEDHASHING,CxmuleDlg::OnFinishedHashing)
   EVT_MENU(TM_DNSDONE,CxmuleDlg::OnDnsDone)
   EVT_CLOSE(CxmuleDlg::OnClose)
+  EVT_MENU(TM_HASHTHREADFINISHED,CxmuleDlg::OnHashingShutdown)
 END_EVENT_TABLE()
 
-/* Razor 1a - Modif by MikaelB
-   Bar size definition, to avoid bar dispaying's bug */
-
-#define STATE_CONNECTED 1
-#define STATE_NORMAL    0
-   
- int bar_x1;
- int bar_y1;
- int bar_x2;
- int bar_y2;
- int state;
-
-/* End modif */
-
 void CxmuleDlg::OnDnsDone(wxCommandEvent& evt)
 {
   CUDPSocket* socket=(CUDPSocket*)evt.GetClientData();
@@ -117,48 +105,34 @@ void CxmuleDlg::OnFinishedHashing(wxCommandEvent& evt)
     requester->PartFileHashFinished(result);
   }
   else{
-    theApp.sharedfiles->filelist->SafeAddKFile(result);
-    theApp.sharedfiles->SafeAddKFile(result);	
+    if(theApp.sharedfiles->filelist->SafeAddKFile(result))
+       theApp.sharedfiles->SafeAddKFile(result);
+    else
+       delete result;
   }
 
   //wxMutexGuiLeave();
   return;
 }
 
-/* Razor 1a - Modif by MikaelB */
-
 void muleDefaultToolbar( wxToolBar *parent )
 {
     parent->SetMargins( 2, 2 );
 
     // First of all, create bar with the Disconnect button
-    parent->AddTool( ID_BUTTONCONNECT, _("Disconnect"),connButImg( 0 ), _("Connect to server") );
+    parent->AddTool( ID_BUTTONCONNECT, _("Connect"),connButImg( 0 ), _("Connect to server") );
     parent->AddSeparator();
     parent->AddCheckTool( ID_BUTTONSERVERS, _("Servers"),xmuleDlgImages( 3 ), wxNullBitmap,  _("Server list") );
-    parent->AddCheckTool( ID_BUTTONTRANSFER, _("Transfer"),xmuleDlgImages( 1 ), wxNullBitmap, _("File transfer") );
     parent->AddCheckTool( ID_BUTTONSEARCH, _("Search"),xmuleDlgImages( 2 ), wxNullBitmap, _("Search files") );
+    parent->AddCheckTool( ID_BUTTONTRANSFER, _("Transfer"),xmuleDlgImages( 1 ), wxNullBitmap, _("File transfer") );
     parent->AddCheckTool( ID_BUTTONSHARED, _("Shared Files"),xmuleDlgImages( 18 ), wxNullBitmap,_("Show shared files") );
     parent->AddCheckTool( ID_BUTTONMESSAGES, _("Messages"),xmuleDlgImages( 21 ), wxNullBitmap,  _("Messages") );
-    parent->AddCheckTool( ID_BUTTONIRC, _("IRC"),xmuleDlgImages( 19 ), wxNullBitmap, _("Internet Relay Chat")); 
+//    parent->AddCheckTool( ID_BUTTONIRC, _("IRC"),xmuleDlgImages( 19 ), wxNullBitmap, _("Internet Relay Chat")); 
     parent->AddCheckTool( ID_BUTTONSTATISTICS, _("Statistics"),xmuleDlgImages( 4 ), wxNullBitmap, _("Show current statistics"));
     parent->AddSeparator();
     parent->AddTool( ID_BUTTONPREFERENCES, _("Preferences"),xmuleDlgImages( 5 ), _("Modify preferences") );
     parent->Realize();
-
-    // Save this bar size
-    parent->GetSize(&bar_x2, &bar_y2);
-    state = STATE_CONNECTED;
-
-    // Then delete the disconnect button and add at its place the connect button
-    parent->DeleteTool(ID_BUTTONCONNECT);
-    parent->InsertTool(0,ID_BUTTONCONNECT,GetResString(IDS_MAIN_BTN_CONNECT),connButImg(0), GetResString(IDS_CONNECTTOANYSERVER));
-    parent->Realize();
-
-    // Save this new bar size
-    parent->GetSize(&bar_x1, &bar_y1);
-    state = STATE_NORMAL;
 }
-/*  End modif */
 
 // CxmuleDlg Dialog
 #include <signal.h>
@@ -173,6 +147,8 @@ CxmuleDlg::CxmuleDlg(wxWindow* pParent, wxString title)
   : wxFrame(pParent,CxmuleDlg::IDD,title,wxDefaultPosition,wxSize(800,520),
 	    wxCAPTION|wxRESIZE_BORDER|wxSYSTEM_MENU|wxDIALOG_NO_PARENT|wxTHICK_FRAME|wxMINIMIZE_BOX|wxMAXIMIZE_BOX|CLOSEBOX)
 {
+  theApp.xmuledlg = this;
+
   m_app_state=APP_STATE_STARTING;
   srand(time(NULL));
 
@@ -255,8 +231,8 @@ CxmuleDlg::CxmuleDlg(wxWindow* pParent, wxString title)
 #endif
   wxToolBar* newbar=new wxToolBar(this,-1,wxDefaultPosition,wxDefaultSize,wxTB_HORIZONTAL|wxNO_BORDER|wxTB_TEXT);
   muleDefaultToolbar(newbar);
-  buttonToolbar->Add(newbar,0,wxGROW|wxALL,5);
-  buttonToolbar->Layout();
+  //buttonToolbar->Add(newbar,0,wxGROW|wxALL,5);
+  //buttonToolbar->Layout();
   m_wndToolbar=newbar;
 
   // initially server page is visible
@@ -278,6 +254,7 @@ CxmuleDlg::CxmuleDlg(wxWindow* pParent, wxString title)
   chatwnd->Show(FALSE);
 
   SetActiveDialog(serverwnd);
+  m_nActiveDialog = 1;
 #if 0
   serverwnd.Show(FALSE);
   contentSizer->Remove(&serverwnd);
@@ -308,20 +285,18 @@ CxmuleDlg::CxmuleDlg(wxWindow* pParent, wxString title)
 	sourceTrayIconGrey= (HICON)LoadImage(AfxGetInstanceHandle() ,MAKEINTRESOURCE(IDR_TRAYICON_GREY),IMAGE_ICON,16,16,LR_DEFAULTCOLOR);
 	usericon = (HICON)::LoadImage(AfxGetInstanceHandle(),MAKEINTRESOURCE(IDI_USER),IMAGE_ICON,16,16,0);
 #endif
-
 /* Razor 1a - Modif by MikaelB
    Set client size and position */
 
   // Create a config base for saving razor preferences
   wxConfigBase *config = wxConfigBase::Get();
   // If config haven't been created
-  if (config == NULL) {
+  if (config == NULL)
     // exit without saving
     return;
-  }
 
   // The section where to save in in file
-  CString section = "/Razor_Preferences/";
+  wxString section = "/Razor_Preferences/";
 
   // Main window location and size
   int x1,y1,x2,y2;
@@ -332,19 +307,25 @@ CxmuleDlg::CxmuleDlg(wxWindow* pParent, wxString title)
   y1 = config->Read(_T(section+"MAIN_Y_POS"), 0l);
   x2 = config->Read(_T(section+"MAIN_X_SIZE"), 0l);
   y2 = config->Read(_T(section+"MAIN_Y_SIZE"), 0l);
+  split_pos = config->Read(_T(section+"SPLITTER_POS"), 0l);
+  printf("split read, found : %u\n",split_pos);
 
   // If x1 and y1 != 0
-  if((x1 != 0) && (y1 != 0)) {
+  if((x1 != 0) && (y1 != 0))
     // Redefine location
     Move(x1,y1);
-  }
-   
+
   // If x2 and y2 != 0
-  if((x2 != 0) && (y2 != 0)) {
+  if((x2 != 0) && (y2 != 0))
     // Redefine size
     SetClientSize(x2,y2);
-  }
+
 /* End modif */
+
+  // Modified tool bar integration... should not have any problems about cut Preferences button
+  SetToolBar(newbar);
+
+  CAddFileThread::Setup();
 }
 
 class QueryDlg : public wxDialog {
@@ -384,14 +365,14 @@ void CxmuleDlg::changeDesktopMode()
     theApp.glob_prefs->SetDesktopMode(mode);
 }
 
-void CxmuleDlg::createSystray()
+void CxmuleDlg::createSystray(const wxString& title)
 {
   // create the docklet (at this point we already have preferences!)
   if(theApp.glob_prefs->GetDesktopMode()==0) {    
     // ok, it's not set yet.
     changeDesktopMode();
   }
-  m_wndTaskbarNotifier=new CSysTray(this,theApp.glob_prefs->GetDesktopMode());
+  m_wndTaskbarNotifier=new CSysTray(this,theApp.glob_prefs->GetDesktopMode(),title);
 }
 
 extern void TimerProc();
@@ -426,8 +407,9 @@ void CxmuleDlg::OnBnStats(wxEvent& ev)
       m_wndToolbar->ToggleTool(lastbutton,FALSE);
       lastbutton=ID_BUTTONSTATISTICS;
       SetActiveDialog(statisticswnd);
+      m_nActiveDialog = 7;
     }
-  UpdateBar();
+  //UpdateBar();
 }
 
 void CxmuleDlg::OnBnShared(wxEvent& ev)
@@ -442,8 +424,9 @@ void CxmuleDlg::OnBnShared(wxEvent& ev)
       m_wndToolbar->ToggleTool(lastbutton,FALSE);
       lastbutton=ID_BUTTONSHARED;
       SetActiveDialog(sharedfileswnd);
+      m_nActiveDialog = 4;
     }
-  UpdateBar();
+  // UpdateBar();
 }
 
 void CxmuleDlg::btnServers(wxEvent& ev)
@@ -458,7 +441,9 @@ void CxmuleDlg::btnServers(wxEvent& ev)
       m_wndToolbar->ToggleTool(lastbutton,FALSE);
       lastbutton=ID_BUTTONSERVERS;
       SetActiveDialog(serverwnd);
+      m_nActiveDialog = 1;
     }
+  // UpdateBar();
 }
 
 void CxmuleDlg::btnSearch(wxEvent& ev)
@@ -473,8 +458,9 @@ void CxmuleDlg::btnSearch(wxEvent& ev)
       m_wndToolbar->ToggleTool(lastbutton,FALSE);
       lastbutton=ID_BUTTONSEARCH;
       SetActiveDialog(searchwnd);
+      m_nActiveDialog = 3;
     }
-
+  // UpdateBar();
 }
 
 void CxmuleDlg::btnTransfer(wxEvent& ev)
@@ -489,7 +475,12 @@ void CxmuleDlg::btnTransfer(wxEvent& ev)
       m_wndToolbar->ToggleTool(lastbutton,FALSE);
       lastbutton=ID_BUTTONTRANSFER;
       SetActiveDialog(transferwnd);
+      m_nActiveDialog = 2;
     }
+  // Set splitter position
+  wxSplitterWindow* split=(wxSplitterWindow*)FindWindow("splitterWnd");
+  split->SetSashPosition(split_pos, true);
+  // UpdateBar();
 }
 
 void CxmuleDlg::OnBnMessages(wxEvent& ev)
@@ -504,8 +495,9 @@ void CxmuleDlg::OnBnMessages(wxEvent& ev)
       m_wndToolbar->ToggleTool(lastbutton,FALSE);
       lastbutton=ID_BUTTONMESSAGES;
       SetActiveDialog(chatwnd);
+      m_nActiveDialog = 5;
     }
-  UpdateBar();
+  // UpdateBar();
 }
 
 void CxmuleDlg::btnPreferences(wxEvent& ev)
@@ -613,6 +605,8 @@ void CxmuleDlg::socketHandler(wxSocketEvent& event)
 
 CxmuleDlg::~CxmuleDlg()
 {
+	printf("Shutting down xMule...\n");
+
 #if 0
 	::DestroyIcon(m_hIcon);
 	::DestroyIcon(connicons[0]);
@@ -639,23 +633,42 @@ CxmuleDlg::~CxmuleDlg()
     return;
 
   // The section where to save in in file
-  CString section = "/Razor_Preferences/";
+  wxString section = "/Razor_Preferences/";
 
   // Main window location and size
   int x1,y1,x2,y2;
   GetPosition(&x1, &y1);
   GetSize(&x2,&y2);
-  
+
   // Saving window size and position
   config->Write(_T(section+"MAIN_X_POS"), (long) x1);
   config->Write(_T(section+"MAIN_Y_POS"), (long) y1);
   config->Write(_T(section+"MAIN_X_SIZE"), (long) x2);
   config->Write(_T(section+"MAIN_Y_SIZE"), (long) y2);
-
+  
+  // Saving sash position of splitter in transfer window
+  wxSplitterWindow* split=(wxSplitterWindow*)FindWindow("splitterWnd");
+  config->Write(_T(section+"SPLITTER_POS"), (long) split_pos);
+  printf("split saved to : %u\n", split_pos);
+	  
   config->Flush(true);
 
-/* End modif */    
+/* End modif */
 
+
+	theApp.OnlineSig(true);
+
+	delete theApp.sharedfiles;
+	delete theApp.serverconnect;
+	delete theApp.serverlist;
+	delete theApp.knownfiles;
+	delete theApp.searchlist;
+	delete theApp.clientcredits;
+	delete theApp.downloadqueue;
+	delete theApp.uploadqueue;
+	delete theApp.clientlist;
+	delete theApp.friendlist;
+	delete theApp.glob_prefs;
 }
 #if 0
 void CxmuleDlg::DoDataExchange(CDataExchange* pDX){
@@ -885,7 +898,7 @@ void CxmuleDlg::OnBnConnect(wxEvent& evt)
   else {     //disconnect if currently connected
     CloseConnection();
   }
-  UpdateBar();
+  // UpdateBar();
 }
 
 void CxmuleDlg::ResetLog(){
@@ -917,6 +930,7 @@ void CxmuleDlg::AddLogLine(bool addtostatusbar,const wxChar* line,...){
 	//  statusbar.SetStatusText(bufferline,0); //,0);
 	  wxStaticText* text=(wxStaticText*)FindWindow("infoLabel");
 	  text->SetLabel(bufferline);
+	Layout();
 	}
 	
 	time_t joskus=time(NULL);
@@ -1009,7 +1023,7 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server,bool iconOnl
   static int __oldstatus=(-1);
   bool changed=false;
 
-  theApp.xmuledlg->serverwnd->UpdateMyInfo();
+  serverwnd->UpdateMyInfo();
 
   if (connected){
     wxStaticBitmap* bmp=(wxStaticBitmap*)FindWindowByName("connImage");
@@ -1034,8 +1048,6 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server,bool iconOnl
       m_wndToolbar->DeleteTool(ID_BUTTONCONNECT);
       m_wndToolbar->InsertTool(0,ID_BUTTONCONNECT,GetResString(IDS_MAIN_BTN_DISCONNECT),connButImg(1),GetResString(IDS_MAIN_BTN_DISCONNECT_TOOLTIP));
       m_wndToolbar->Realize();
-      state = STATE_CONNECTED;
-      UpdateBar();
     }
 
     /*
@@ -1051,6 +1063,7 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server,bool iconOnl
     wxStaticText* tx=(wxStaticText*)FindWindow("infoLabel");
     tx->SetLabel(GetResString(IDS_MAIN_CONNECTEDTO)+wxString(server));
     ((wxStaticText*)FindWindow("connLabel"))->SetLabel(server);
+    Layout();
     //statusbar.SetTipText(3,server);
     //statusbar.SetText(server,3,0);
   }
@@ -1077,6 +1090,7 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server,bool iconOnl
       
       // EI INFOLABEL
       ((wxStaticText*)FindWindowByName("connLabel"))->SetLabel(GetResString(IDS_CONNECTING));
+      Layout();
       //statusbar.SetText(GetResString(IDS_CONNECTING),3,0);
       //statusbar.SetTipText(3,"");
       ShowUserCount(0,0);
@@ -1085,15 +1099,14 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server,bool iconOnl
       if(__oldstatus!=STAT_NOTCONNECTED) {
 	bmp->SetBitmap(connImages(0));
 	((wxStaticText*)FindWindowByName("connLabel"))->SetLabel(GetResString(IDS_NOTCONNECTED));
+      Layout();
       //butn->SetLabel(GetResString(IDS_MAIN_BTN_CONNECT));
       //butn->SetDefaultBitmap(connButImg(0));
       // and again...
 	m_wndToolbar->DeleteTool(ID_BUTTONCONNECT);
 	m_wndToolbar->InsertTool(0,ID_BUTTONCONNECT,GetResString(IDS_MAIN_BTN_CONNECT),connButImg(0),
 				 GetResString(IDS_CONNECTTOANYSERVER));
-	state = STATE_NORMAL;
 	m_wndToolbar->Realize();
-	UpdateBar();
 	__oldstatus=STAT_NOTCONNECTED;
       }
       /*
@@ -1104,7 +1117,8 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server,bool iconOnl
 	statusbar.SetText(GetResString(IDS_NOTCONNECTED),3,0);
       */
       ((wxStaticText*)FindWindow("connLabel"))->SetLabel(GetResString(IDS_NOTCONNECTED));
-      theApp.xmuledlg->AddLogLine(true,GetResString(IDS_DISCONNECTED));
+      Layout();
+      AddLogLine(true,GetResString(IDS_DISCONNECTED));
       //statusbar.SetTipText(3,"");
       ShowUserCount(0,0);
     }
@@ -1120,6 +1134,7 @@ void CxmuleDlg::ShowUserCount(uint32 user_toshow,uint32 file_toshow){
   char buffer[100];
   sprintf(buffer, "%s: %s(%s) | %s: %s(%s)", GetResString(IDS_UUSERS).GetData(), CastItoIShort(user_toshow).GetData(), CastItoIShort(totaluser).GetData(), GetResString(IDS_FILES).GetData(), CastItoIShort(file_toshow).GetData(), CastItoIShort(totalfile).GetData());
   wxStaticCast(FindWindow("userLabel"),wxStaticText)->SetLabel(buffer);
+  Layout();
   //statusbar.SetText(buffer,1,0);
 }
 
@@ -1142,6 +1157,7 @@ void CxmuleDlg::ShowTransferRate(bool foreceAll){
 		sprintf(buffer,GetResString(IDS_UPDOWNSMALL),(float)lastuprate/1024, (float)lastdownrate/1024);
 	//statusbar.SetStatusText(buffer,2); //,0);
 	((wxStaticText*)FindWindowByName("speedLabel"))->SetLabel(buffer);
+	Layout();
 
 	// set trayicon-icon
 	int DownRateProcent=(int)ceil ( (lastdownrate/10.24)/ theApp.glob_prefs->GetMaxGraphDownloadRate());
@@ -1246,7 +1262,7 @@ LRESULT CxmuleDlg::OnWMData(WPARAM wParam,LPARAM lParam){
 					_ASSERT( pListLink !=0 ); 
 					CString strAddress = pListLink->GetAddress(); 
 					if(strAddress.GetLength() != 0)
-						theApp.xmuledlg->serverwnd.UpdateServerMetFromURL(strAddress);
+						serverwnd.UpdateServerMetFromURL(strAddress);
 				}
 				break;
 			case CED2KLink::kServer:
@@ -1260,9 +1276,9 @@ LRESULT CxmuleDlg::OnWMData(WPARAM wParam,LPARAM lParam){
 					_ASSERT( pSrv !=0 );
 					pSrvLink->GetDefaultName(defName);
 					pSrv->SetListName(defName.GetBuffer());
-					if (!theApp.xmuledlg->serverwnd.serverlistctrl.AddServer(pSrv,true)) 
+					if (!serverwnd.serverlistctrl.AddServer(pSrv,true)) 
 						delete pSrv; 
-					else theApp.xmuledlg->AddLogLine(true,GetResString(IDS_SERVERADDED)+CString(pSrv->GetListName()));
+					else AddLogLine(true,GetResString(IDS_SERVERADDED)+"%s", pSrv->GetListName());
 				}
 				break;
 			default:
@@ -1292,6 +1308,17 @@ LRESULT CxmuleDlg::OnFileHashed(WPARAM wParam,LPARAM lParam){
 }
 #endif
 
+void CxmuleDlg::OnHashingShutdown(wxCommandEvent&)
+{
+	if ( m_app_state != APP_STATE_SHUTINGDOWN ) {
+		printf("Hashing thread ended, restarting\n");
+		CAddFileThread::Setup();
+	} else {
+		printf("Hashing thread terminated, ready to shutdown\n");
+		Destroy();
+	}
+}
+
 void CxmuleDlg::OnClose(wxCloseEvent& evt)
 {
   if (evt.CanVeto() && theApp.glob_prefs->IsConfirmExitEnabled() )
@@ -1301,10 +1328,17 @@ void CxmuleDlg::OnClose(wxCloseEvent& evt)
     }
 
   // we are going DOWN
-  theApp.xmuledlg->m_app_state=APP_STATE_SHUTINGDOWN;
+  m_app_state=APP_STATE_SHUTINGDOWN;
 
   theApp.OnlineSig(); // Added By Bouc7 
-  
+
+  // Close sockets to avoid new clients coming in
+  theApp.listensocket->Destroy();
+  theApp.clientudp->Destroy();
+
+  // Signal the hashing thread to terminate
+  CAddFileThread::Shutdown();
+
   // TODO: Add your message handler code here and/or call default
   //WINDOWPLACEMENT wp;wp.length=sizeof(wp);GetWindowPlacement(&wp);
   //theApp.glob_prefs->SetWindowLayout(wp);
@@ -1329,10 +1363,11 @@ void CxmuleDlg::OnClose(wxCloseEvent& evt)
   transferwnd->downloadlistctrl->DeleteAllItems();
   //xmuledlg->chatwnd->chatselector->DeleteAllItems();
   theApp.clientlist->DeleteAll();
-  if(searchwnd->searchlistctrl) searchwnd->searchlistctrl->DeleteAllItems();
+//  if(searchwnd->searchlistctrl) searchwnd->searchlistctrl->DeleteAllItems();
 
-  // and destroy the window
-  Destroy();
+  // Hint: Destroying the window is delayed until the hashing thread
+  //       does signal its termination.
+//  Destroy();
   //CTrayDialog::OnCancel();
 }
 
@@ -1572,14 +1607,3 @@ void CxmuleDlg::OnQLTimer(wxTimerEvent& evt)
     return;
   CQueueListCtrl::QueueUpdateTimer();
 }
-
-/* Razor */
-void CxmuleDlg::UpdateBar()
-{
-    int x,y;
-    GetSize(&x,&y);
-    if((state == STATE_NORMAL) && ((x != bar_x1) || (y != bar_y1)))
-      m_wndToolbar->SetSize(bar_x1,bar_y1);
-    else if((state == STATE_CONNECTED) && ((x != bar_x2) || (y != bar_y2)))
-      m_wndToolbar->SetSize(bar_x2,bar_y2);
-}  
