@@ -87,7 +87,7 @@ public:
 	bool			IsRunning();
 	void			DoVersioncheck(bool manual);
 	// has to be done in own method
-	void createSystray();
+	void createSystray(const wxString& title);
 	void changeDesktopMode();
 
 	CTransferWnd*	transferwnd;
@@ -127,6 +127,7 @@ protected:
 
  public:
 	void OnFinishedHashing(wxCommandEvent& evt);
+	void OnHashingShutdown(wxCommandEvent& evt);
 	void OnDnsDone(wxCommandEvent& evt);
 
 	void InitDialog();
@@ -163,6 +164,9 @@ protected:
 	*/
 	void OnBnConnect(wxEvent& evt);
 	void OnClose(wxCloseEvent& evt);
+
+	/* Public function to check which tab is active. Needed to check what to redraw. */
+	int GetActiveDialog()	{return m_nActiveDialog;}
 private:
 	wxString			logtext;
 	bool			ready;	
@@ -198,7 +202,10 @@ private:
 	void CloseConnection();
 	void RestoreWindow();
 	void UpdateTrayIcon(int procent);
-	void UpdateBar();
+
+	int m_nActiveDialog;	
+public:
+    int split_pos;
 };
 
 
